love = {
	modules = {
		{
			name = 'audio',
			description = 'Provides an interface to create noise with the user\'s speakers.',
			types = {
				{
					name = 'Source',
					description = 'A Source represents audio you can play back. You can do interesting things with Sources, like set the volume, pitch, and its position relative to the listener.',
					constructors = {
						'newSource'
					},
					functions = {
						{
							name = 'getDirection',
							description = 'Gets the direction of the Source.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The X part of the direction vector.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The Y part of the direction vector.'
										},
										{
											type = 'number',
											name = 'z',
											description = 'The Z part of the direction vector.'
										}
									}
								}
							}
						},
						{
							name = 'getDistance',
							description = 'Returns the reference and maximum distance of the source.',
							functions = {
								{
									returns = {
										{
											type = 'string',
											name = 'ref',
											description = 'The reference distance.'
										},
										{
											type = 'string',
											name = 'max',
											description = 'The maximum distance.'
										}
									}
								}
							}
						},
						{
							name = 'getPitch',
							description = 'Gets the current pitch of the Source.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'pitch',
											description = 'The pitch, where 1.0 is normal.'
										}
									}
								}
							}
						},
						{
							name = 'getPosition',
							description = 'Gets the position of the Source.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The X position of the Source.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The Y position of the Source.'
										},
										{
											type = 'number',
											name = 'z',
											description = 'The Z position of the Source.'
										}
									}
								}
							}
						},
						{
							name = 'getVelocity',
							description = 'Gets the velocity of the Source.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The X part of the velocity vector.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The Y part of the velocity vector.'
										},
										{
											type = 'number',
											name = 'z',
											description = 'The Z part of the velocity vector.'
										}
									}
								}
							}
						},
						{
							name = 'getVolume',
							description = 'Gets the current volume of the Source.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'volume',
											description = 'The volume of the Source, where 1.0 is normal volume.'
										}
									}
								}
							}
						},
						{
							name = 'isLooping',
							description = 'Returns whether the Source will loop.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'loop',
											description = 'True if the Source will loop, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isPaused',
							description = 'Returns whether the Source is paused.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'paused',
											description = 'True if the Source is paused, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isStatic',
							description = 'Returns whether the Source is static.\n\nSee SourceType.static definition to have more informations.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'static',
											description = 'True if the Source is static, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isStopped',
							description = 'Returns whether the Source is stopped.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'stopped',
											description = 'True if the Source is stopped, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'pause',
							description = 'Pauses the Source.',
							functions = {
								{}
							}
						},
						{
							name = 'play',
							description = 'Starts playing the Source.',
							functions = {
								{}
							}
						},
						{
							name = 'resume',
							description = 'Resumes a paused Source.',
							functions = {
								{}
							}
						},
						{
							name = 'rewind',
							description = 'Rewinds a Source.',
							functions = {
								{}
							}
						},
						{
							name = 'seek',
							description = 'Sets the currently playing position of the Source.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'offset',
											description = 'The position to seek to.'
										},
										{
											type = 'TimeUnit',
											name = 'unit',
											default = '"seconds"',
											description = 'The unit of the position value.'
										}
									}
								}
							}
						},
						{
							name = 'setDirection',
							description = 'Sets the direction vector of the Source. A zero vector makes the source non-directional.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The X part of the direction vector.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The Y part of the direction vector.'
										},
										{
											type = 'number',
											name = 'z',
											description = 'The Z part of the direction vector.'
										}
									}
								}
							}
						},
						{
							name = 'setLooping',
							description = 'Sets whether the Source should loop.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'loop',
											description = 'True if the source should loop, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'setPitch',
							description = 'Sets the pitch of the Source.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'pitch',
											description = 'Calculated with regard to 1 being the base pitch. Each reduction by 50 percent equals a pitch shift of -12 semitones (one octave reduction). Each doubling equals a pitch shift of 12 semitones (one octave increase). Zero is not a legal value.'
										}
									}
								}
							}
						},
						{
							name = 'setPosition',
							description = 'Sets the position of the Source.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The X position of the Source.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The Y position of the Source.'
										},
										{
											type = 'number',
											name = 'z',
											description = 'The Z position of the Source.'
										}
									}
								}
							}
						},
						{
							name = 'setVelocity',
							description = 'Sets the velocity of the Source.\n\nThis does not change the position of the Source, but lets the application know how it has to calculate the doppler effect.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The X part of the velocity vector.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The Y part of the velocity vector.'
										},
										{
											type = 'number',
											name = 'z',
											description = 'The Z part of the velocity vector.'
										}
									}
								}
							}
						},
						{
							name = 'setVolume',
							description = 'Sets the volume of the Source.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'volume',
											description = 'The volume of the Source, where 1.0 is normal volume.'
										}
									}
								}
							}
						},
						{
							name = 'stop',
							description = 'Stops a Source.',
							functions = {
								{}
							}
						},
						{
							name = 'tell',
							description = 'Stops a Source.',
							functions = {
								{
									arguments = {
										{
											type = 'TimeUnit',
											name = 'unit',
											default = '"seconds"',
											description = 'The type of unit for the return value.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'position',
											description = 'The currently playing position of the Source.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'getDistanceModel',
					description = 'Returns the distance attenuation model.',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'model',
									description = 'The current distance model.'
								}
							}
						}
					}
				},
				{
					name = 'getNumSources',
					description = 'Gets the current number of simulatenous playing sources.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'numSources',
									description = 'The current number of simulatenous playing sources'
								}
							}
						}
					}
				},
				{
					name = 'getOrientation',
					description = 'Returns the orientation of the listener.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'fx',
									description = 'The X component of the forward vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'fy',
									description = 'The Y component of the forward vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'fz',
									description = 'The Z component of the forward vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'ux',
									description = 'The X component of the up vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'uy',
									description = 'The Y component of the up vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'uz',
									description = 'The Z component of the up vector of the listener orientation.'
								}
							}
						}
					}
				},
				{
					name = 'getPosition',
					description = 'Returns the position of the listener.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'x',
									description = 'The X position of the listener.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The Y position of the listener.'
								},
								{
									type = 'number',
									name = 'z',
									description = 'The Z position of the listener.'
								}
							}
						}
					}
				},
				{
					name = 'getVelocity',
					description = 'Returns the velocity of the listener.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'x',
									description = 'The X velocity of the listener.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The Y velocity of the listener.'
								},
								{
									type = 'number',
									name = 'z',
									description = 'The Z velocity of the listener.'
								}
							}
						}
					}
				},
				{
					name = 'getVolume',
					description = 'Returns the master volume.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'volume',
									description = 'The current master volume.'
								}
							}
						}
					}
				},
				{
					name = 'newSource',
					description = 'Creates a new Source from a file, SoundData, or Decoder. Sources created from SoundData are always static.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'file',
									description = 'The file to create a Source from.'
								},
								{
									type = 'SourceType',
									name = 'type',
									description = 'Streaming or static source.'
								}
							},
							returns = {
								{
									type = 'Source',
									name = 'source',
									description = 'A new Source that can play the specified audio.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'SoundData',
									name = 'data',
									description = 'The SoundData to create a Source from.'
								}
							},
							returns = {
								{
									type = 'Source',
									name = 'source',
									description = 'A new Source that can play the specified audio. The SourceType of the returned audio is "static".'
								}
							}
						},
						{
							arguments = {
								{
									type = 'Decoder',
									name = 'decoder',
									description = 'The Decoder to create a Source from.'
								},
								{
									type = 'SourceType',
									name = 'type',
									description = 'Streaming or static source.'
								}
							},
							returns = {
								{
									type = 'Source',
									name = 'source',
									description = 'A new Source that can play the specified audio.'
								}
							}
						}
					}
				},
				{
					name = 'pause',
					description = 'Pauses all audio',
					functions = {
						{},
						{
							arguments = {
								{
									type = 'Source',
									name = 'source',
									description = 'The source on which to pause the playback.'
								}
							}
						}
					}
				},
				{
					name = 'play',
					description = 'Plays the specified Source.',
					functions = {
						{
							arguments = {
								{
									type = 'Source',
									name = 'source',
									description = 'The Source to play.'
								}
							}
						}
					}
				},
				{
					name = 'resume',
					description = 'Resumes all audio',
					functions = {
						{},
						{
							arguments = {
								{
									type = 'Source',
									name = 'source',
									description = 'The source on which to resume the playback.'
								}
							}
						}
					}
				},
				{
					name = 'rewind',
					description = 'Rewinds all playing audio.',
					functions = {
						{},
						{
							arguments = {
								{
									type = 'Source',
									name = 'source',
									description = 'The source to rewind.'
								}
							}
						}
					}
				},
				{
					name = 'setDistanceModel',
					description = 'Sets the distance attenuation model.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'model',
									description = 'The new distance model.'
								}
							}
						}
					}
				},
				{
					name = 'setOrientation',
					description = 'Sets the orientation of the listener.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'fx',
									description = 'The X component of the forward vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'fy',
									description = 'The Y component of the forward vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'fz',
									description = 'The Z component of the forward vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'ux',
									description = 'The X component of the up vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'uy',
									description = 'The Y component of the up vector of the listener orientation.'
								},
								{
									type = 'number',
									name = 'uz',
									description = 'The Z component of the up vector of the listener orientation.'
								}
							}
						}
					}
				},
				{
					name = 'setPosition',
					description = 'Sets the position of the listener, which determines how sounds play.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'x',
									description = 'The X position of the listener.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The Y position of the listener.'
								},
								{
									type = 'number',
									name = 'z',
									description = 'The Z position of the listener.'
								}
							}
						}
					}
				},
				{
					name = 'setVelocity',
					description = 'Sets the velocity of the listener.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'x',
									description = 'The X velocity of the listener.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The Y velocity of the listener.'
								},
								{
									type = 'number',
									name = 'z',
									description = 'The Z velocity of the listener.'
								}
							}
						}
					}
				},
				{
					name = 'setVolume',
					description = 'Sets the master volume.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'volume',
									description = '1.0f is max and 0.0f is off.'
								}
							}
						}
					}
				},
				{
					name = 'stop',
					description = 'Stops all playing audio.',
					functions = {
						{},
						{
							arguments = {
								{
									type = 'Source',
									name = 'source',
									description = 'The source on which to stop the playback.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'SourceType',
					description = 'Types of audio sources.',
					constants = {
						{
							name = 'static',
							description = 'Decode the entire sound at once.'
						},
						{
							name = 'stream',
							description = 'Stream the sound; decode it gradually.'
						}
					}
				},
				{
					name = 'TimeUnit',
					description = 'Units that represent time.',
					constants = {
						{
							name = 'seconds',
							description = 'Regular seconds.'
						},
						{
							name = 'samples',
							description = 'Audio samples.'
						}
					}
				}
			}
		},
		{
			name = 'event',
			description = 'Manages events, like keypresses.',
			functions = {
				{
					name = 'clear',
					description = 'Clears the event queue.',
					functions = {
						{}
					}
				},
				{
					name = 'poll',
					description = 'Returns an iterator for messages in the event queue.',
					functions = {
						{
							returns = {
								{
									type = 'function',
									name = 'i',
									description = 'Iterator function usable in a for loop.'
								}
							}
						}
					}
				},
				{
					name = 'pump',
					description = 'Pump events into the event queue. This is a low-level function, and is usually not called explicitly, but implicitly by love.event.poll() or love.event.wait().',
					functions = {
						{}
					}
				},
				{
					name = 'push',
					description = 'Adds an event to the event queue.',
					functions = {
						{
							arguments = {
								{
									type = 'Event',
									name = 'e',
									description = 'The name of the event.'
								},
								{
									type = 'mixed',
									name = 'a',
									default = nil,
									description = 'First event argument.'
								},
								{
									type = 'mixed',
									name = 'b',
									default = nil,
									description = 'Second event argument.'
								},
								{
									type = 'mixed',
									name = 'c',
									default = nil,
									description = 'Third event argument.'
								},
								{
									type = 'mixed',
									name = 'd',
									default = nil,
									description = 'Fourth event argument.'
								}
							}
						}
					}
				},
				{
					name = 'quit',
					description = 'Adds the quit event to the queue.\n\nThe quit event is a signal for the event handler to close LVE. It\'s possible to abort the exit process with the love.quit callback.',
					functions = {
						{}
					}
				},
				{
					name = 'wait',
					description = 'Like love.event.poll(), but blocks until there is an event in the queue.',
					functions = {
						{
							returns = {
								{
									type = 'Event',
									name = 'e',
									description = 'The type of event.'
								},
								{
									type = 'mixed',
									name = 'a',
									description = 'First event argument.'
								},
								{
									type = 'mixed',
									name = 'b',
									description = 'Second event argument.'
								},
								{
									type = 'mixed',
									name = 'c',
									description = 'Third event argument.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'Event',
					constants = {
						{
							name = 'focus',
							description = 'Window focus gained or lost'
						},
						{
							name = 'joystickpressed',
							description = 'Joystick pressed'
						},
						{
							name = 'joystickreleased',
							description = 'Joystick released'
						},
						{
							name = 'keypressed',
							description = 'Key pressed'
						},
						{
							name = 'keyreleased',
							description = 'Key releaed'
						},
						{
							name = 'mousepressed',
							description = 'Mouse pressed'
						},
						{
							name = 'mousereleased',
							description = 'Mouse released'
						},
						{
							name = 'quit',
							description = 'Quit'
						},
					}
				}
			}
		},
		{
			name = 'filesystem',
			description = 'Provides an interface to the user\'s filesystem.',
			types = {
				{
					name = 'File',
					description = 'Represents a file on the filesystem.',
					constructors = {
						'newFile'
					},
					functions = {
						{
							name = 'close',
							description = 'Closes a file.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'success',
											description = 'Whether closing was successful.'
										}
									}
								}
							}
						},
						{
							name = 'eof',
							description = 'If the end-of-file has been reached',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'eof',
											description = 'Whether EOF has been reached.'
										}
									}
								}
							}
						},
						{
							name = 'getSize',
							description = 'Returns the file size.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'size',
											description = 'The file size'
										}
									}
								}
							}
						},
						{
							name = 'lines',
							description = 'Iterate over all the lines in a file',
							functions = {
								{
									returns = {
										{
											type = 'function',
											name = 'iterator',
											description = 'The iterator (can be used in for loops)'
										}
									}
								}
							}
						},
						{
							name = 'open',
							description = 'Open the file for write, read or append.\n\nIf you are getting the error message "Could not set write directory", try setting the save directory. This is done either with love.filesystem.setIdentity or by setting the identity field in love.conf.',
							functions = {
								{
									arguments = {
										{
											type = 'FileMode',
											name = 'mode',
											description = 'The mode to open the file in.'
										}
									},
									returns = {
										{
											type = 'boolean',
											name = 'ok',
											description = 'True on success, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'read',
							description = 'Read a number of bytes from a file.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'bytes',
											description = 'The number of bytes to read'
										}
									},
									returns = {
										{
											type = 'string',
											name = 'contents',
											description = 'The contents of the read bytes.'
										}
									}
								}
							}
						},
						{
							name = 'seek',
							description = 'Seek to a position in a file.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'pos',
											description = 'The position to seek to.'
										}
									},
									returns = {
										{
											type = 'boolean',
											name = 'success',
											description = 'Whether the operation was successful.'
										}
									}
								}
							}
						},
						{
							name = 'write',
							description = 'Write data to a file.',
							functions = {
								{
									arguments = {
										{
											type = 'string',
											name = 'data',
											description = 'The data to write.'
										}
									},
									returns = {
										{
											type = 'boolean',
											name = 'success',
											description = 'Whether the operation was successful.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'FileData',
					description = 'Represents a file on the filesystem.',
					functions = {
						{
							name = 'getExtension',
							description = 'Gets the extension of the FileData.',
							functions = {
								{
									returns = {
										{
											type = 'string',
											name = 'ext',
											description = 'The extension of the file the FileData represents.'
										}
									}
								}
							}
						},
						{
							name = 'getFilename',
							description = 'Gets the filename of the FileData.',
							functions = {
								{
									returns = {
										{
											type = 'string',
											name = 'name',
											description = 'The name of the file the FileData represents.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Data',
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'enumerate',
					description = 'Returns a table with the names of files and subdirectories in the directory in an undefined order.\n\nNote that this directory is relative to the love folder/archive being run. Absolute paths will not work.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'dir',
									description = 'The directory.'
								}
							},
							returns = {
								{
									type = 'table',
									name = 'files',
									description = 'A sequence with the names of all files and subdirectories as strings.'
								}
							}
						}
					}
				},
				{
					name = 'exists',
					description = 'Check whether a file or directory exists.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The path to a potential file or directory.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'e',
									description = 'True if there is a file or directory with the specified name. False otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'getAppdataDirectory',
					description = 'Returns the application data directory (could be the same as getUserDirectory)',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'path',
									description = 'The path of the application data directory.'
								}
							}
						}
					}
				},
				{
					name = 'getLastModified',
					description = 'Gets the last modification time of a file.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The path and name to a file.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'modtime',
									description = 'The last modification time in seconds since the unix epoch or nil on failure.'
								},
								{
									type = 'string',
									name = 'errormsg',
									description = 'The error message on failure.'
								}
							}
						}
					}
				},
				{
					name = 'getSaveDirectory',
					description = 'Gets the full path to the designated save directory. This can be useful if you want to use the standard io library (or something else) to read or write in the save directory.',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'dir',
									description = 'The absolute path to the save directory.'
								}
							}
						}
					}
				},
				{
					name = 'getUserDirectory',
					description = 'Returns the path of the user\'s directory.',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'path',
									description = 'The path of the user\'s directory.'
								}
							}
						}
					}
				},
				{
					name = 'getWorkingDirectory',
					description = 'Gets the current working directory.',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'cwd',
									description = 'The current working directory.'
								}
							}
						}
					}
				},
				{
					name = 'init',
					description = 'Initializes love.filesystem, will be called internally, so should not be used explicitly.',
					functions = {
						{}
					}
				},
				{
					name = 'isDirectory',
					description = 'Check whether something is a directory.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The path to a potential directory.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'is_dir',
									description = 'True if there is a directory with the specified name. False otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'isFile',
					description = 'Check whether something is a file.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The path to a potential file.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'is_file',
									description = 'True if there is a file with the specified name. False otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'lines',
					description = 'Iterate over the lines in a file.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name (and path) of the file.'
								}
							},
							returns = {
								{
									type = 'function',
									name = 'iterator',
									description = 'A function that iterates over all the lines in the file.'
								}
							}
						}
					}
				},
				{
					name = 'load',
					description = 'Load a file (but not run it).',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name (and path) of the file.'
								}
							},
							returns = {
								{
									type = 'function',
									name = 'chunk',
									description = 'The loaded chunk.'
								}
							}
						}
					}
				},
				{
					name = 'mkdir',
					description = 'Creates a directory.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The directory to create.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'ok',
									description = 'True if the directory was created, false if not.'
								}
							}
						}
					}
				},
				{
					name = 'newFile',
					description = 'Creates a new File object. It needs to be opened before it can be accessed.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The filename of the file to read.'
								}
							},
							returns = {
								{
									type = 'File',
									name = 'file',
									description = 'The new File object.'
								}
							}
						}
					}
				},
				{
					name = 'newFileData',
					description = 'Creates a new FileData object.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'contents',
									description = 'The contents of the file.'
								},
								{
									type = 'string',
									name = 'name',
									description = 'The name of the file.'
								},
								{
									type = 'FileDecoder',
									name = 'decoder',
									description = 'The method to use when decoding the contents.'
								}
							},
							returns = {
								{
									type = 'FileData',
									name = 'data',
									description = 'Your new FileData.'
								}
							}
						}
					}
				},
				{
					name = 'read',
					description = 'Read the contents of a file.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name (and path) of the file.'
								},
								{
									type = 'number',
									name = 'size',
									default = 'all',
									description = 'How many bytes to read.'
								}
							},
							returns = {
								{
									type = 'string',
									name = 'contents',
									description = 'The file contents.'
								},
								{
									type = 'number',
									name = 'size',
									description = 'How many bytes have been read.'
								}
							}
						}
					}
				},
				{
					name = 'remove',
					description = 'Removes a file (or directory).',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The file or directory to remove.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'ok',
									description = 'True if the file/directory was removed, false otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'setIdentity',
					description = 'Sets the write directory for your game. Note that you can only set the name of the folder to store your files in, not the location.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The new identity that will be used as write directory.'
								}
							}
						}
					}
				},
				{
					name = 'setSource',
					description = 'Sets the source of the game, where the code is present, can only be called once, done automatically.',
					functions = {
						{}
					}
				},
				{
					name = 'write',
					description = 'Write data to a file.\n\nIf you are getting the error message "Could not set write directory", try setting the save directory. This is done either with love.filesystem.setIdentity or by setting the identity field in love.conf.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name (and path) of the file.'
								},
								{
									type = 'string',
									name = 'data',
									description = 'The data that should be written to the file'
								},
								{
									type = 'number',
									name = 'size',
									default = 'all',
									description = 'How many bytes to write.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'success',
									description = 'If the operation was successful'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'FileDecoder',
					description = 'How to decode a given FileData.',
					constants = {
						{
							name = 'file',
							description = 'The data is unencoded.'
						},
						{
							name = 'base64',
							description = 'The data is base64-encoded.'
						}
					}
				},
				{
					name = 'FileMode',
					description = 'The different modes you can open a file in.',
					constants = {
						{
							name = 'r',
							description = 'Open a file for read.'
						},
						{
							name = 'w',
							description = 'Open a file for write.'
						},
						{
							name = 'a',
							description = 'Open a file for append.'
						}
					}
				}
			}
		},
		{
			name = 'font',
			description = 'Allows you to work with fonts.',
			types = {
				{
					name = 'FontData',
					description = 'A FontData represents a font, containing the font Rasterizer and its glyphs.',
					constructors = {
						'newFontData'
					},
					supertypes = {
						'Data',
						'Object'
					}
				},
				{
					name = 'GlyphData',
					description = 'A GlyphData represents a drawable symbol of a font Rasterizer.',
					constructors = {
						'newGlyphData'
					},
					supertypes = {
						'Data',
						'Object'
					}
				},
				{
					name = 'Rasterizer',
					description = 'A Rasterizer handles font rendering, containing the font data (image or true-type font) and drawable glyphs.',
					constructors = {
						'newRasterizer'
					},
					supertypes = {
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'newFontData',
					description = 'Creates a new FontData.',
					functions = {
						{
							arguments = {
								{
									type = 'Rasterizer',
									name = 'rasterizer',
									description = 'The Rasterizer containing the font.'
								}
							},
							returns = {
								{
									type = 'FontData',
									name = 'fontData',
									description = 'The FontData.'
								}
							}
						}
					}
				},
				{
					name = 'newGlyphData',
					description = 'Creates a new GlyphData.',
					functions = {
						{
							arguments = {
								{
									type = 'Rasterizer',
									name = 'rasterizer',
									description = 'The Rasterizer containing the font.'
								},
								{
									type = 'number',
									name = 'glyph',
									description = 'The character code of the glyph.'
								}
							},
							returns = {
								{
									type = 'GlyphData',
									name = 'glyphData',
									description = 'The GlyphData.'
								}
							}
						}
					}
				},
				{
					name = 'newRasterizer',
					description = 'Creates a new Rasterizer.',
					functions = {
						{
							arguments = {
								{
									type = 'ImageData',
									name = 'imageData',
									description = 'The image data containing the drawable pictures of font glyphs.'
								},
								{
									type = 'string',
									name = 'glyphs',
									description = 'The sequence of glyphs in the imagedata.'
								}
							},
							returns = {
								{
									type = 'Rasterizer',
									name = 'rasterizer',
									description = 'The rasterizer.'
								}
							}
						}
					}
				}
			}
		},
		{
			name = 'graphics',
			description = 'The primary responsibility for the love.graphics module is the drawing of lines, shapes, text, Images and other Drawable objects onto the screen. Its secondary responsibilities include loading external files (including Images and Fonts) into memory, creating specialized objects (such as ParticleSystems or Framebuffers) and managing screen geometry.\n\nLVE\'s coordinate system is rooted in the upper-left corner of the screen, which is at location (0, 0). The x axis is horizontal: larger values are further to the right. The y axis is vertical: larger values are further towards the bottom.\n\nIn many cases, you draw images or shapes in terms of their upper-left corner (See the picture above).\n\nMany of the functions are used to manipulate the graphics coordinate system, which is essentially the the way coordinates are mapped to the display. You can change the position, scale, and even rotation in this way.',
			types = {
				{
					name = 'Canvas',
					description = 'A Canvas is used for off-screen rendering. Think of it as an invisible screen that you can draw to, but that will not be visible until you draw it to the actual visible screen. It is also known as "render to texture".\n\nBy drawing things that do not change position often (such as background items) to the Canvas, and then drawing the entire Canvas instead of each item, you can reduce the number of draw operations performed each frame.',
					constructors = {
						'newCanvas'
					},
					functions = {
						{
							name = 'clear',
							description = 'Clears content of a Canvas.\n\nWhen called without arguments, the Canvas will be cleared with color rgba = {0,0,0,0}, i.e. it will be fully transparent. If called with color parameters (be it numbers or a color table), the alpha component may be omitted in which case it defaults to 255 (fully opaque).',
							functions = {
								{
									{},
									arguments = {
										{
											type = 'number',
											name = 'red',
											description = 'Red component of the clear color (0-255).'
										},
										{
											type = 'number',
											name = 'green',
											description = 'Green component of the clear color (0-255).'
										},
										{
											type = 'number',
											name = 'blue',
											description = 'Blue component of the clear color (0-255).'
										},
										{
											type = 'number',
											name = 'alpha',
											default = '255',
											description = 'Alpha component of the clear color (0-255).'
										}
									},
									{
										arguments = {
											{
												type = 'table',
												name = 'rgba',
												description = 'A sequence with the red, green, blue and alpha values as numbers (alpha may be ommitted).'
											}
										}
									}
								}
							}
						},
						{
							name = 'getImageData',
							description = 'Returns the image data stored in the Canvas. Think of it as taking a screenshot of the hidden screen that is the Canvas.',
							functions = {
								{
									returns = {
										{
											type = 'ImageData',
											name = 'data',
											description = 'The image data stored in the Canvas.'
										}
									}
								}
							}
						},
						{
							name = 'getWrap',
							description = 'Gets the wrapping properties of a Canvas.\n\nThis functions returns the currently set horizontal and vertical wrapping modes for the Canvas.',
							functions = {
								{
									returns = {
										{
											type = 'WrapMode',
											name = 'horiz',
											description = 'Horizontal wrapping mode of the Canvas.'
										},
										{
											type = 'WrapMode',
											name = 'vert',
											description = 'Vertical wrapping mode of the Canvas.'
										}
									}
								}
							}
						},
						{
							name = 'renderTo',
							description = 'Render to the Canvas using a function.',
							functions = {
								{
									arguments = {
										{
											type = 'function',
											name = 'func',
											description = 'A function performing drawing operations.'
										}
									}
								}
							}
						},
						{
							name = 'setWrap',
							description = 'Sets the wrapping properties of a Canvas.\n\n This function sets the way the edges of a Canvas are treated if it is scaled or rotated. If the WrapMode is set to "clamp", the edge will not be interpolated. If set to "repeat", the edge will be interpolated with the pixels on the opposing side of the framebuffer.',
							functions = {
								{
									arguments = {
										{
											type = 'WrapMode',
											name = 'horiz',
											description = 'Horizontal wrapping mode of the Canvas.'
										},
										{
											type = 'WrapMode',
											name = 'vert',
											description = 'Vertical wrapping mode of the Canvas.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'Font',
					description = 'Defines the shape of characters than can be drawn onto the screen.',
					constructors = {
						'newFont',
						'newImageFont'
					},
					functions = {
						{
							name = 'getHeight',
							description = 'Gets the height of the Font. The height of the font is the size including any spacing; the height which it will need.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'height',
											description = 'The height of the Font in pixels.'
										}
									}
								}
							}
						},
						{
							name = 'getLineHeight',
							description = 'Gets the line height. This will be the value previously set by Font:setLineHeight, or 1.0 by default.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'height',
											description = 'The current line height.'
										}
									}
								}
							}
						},
						{
							name = 'getWidth',
							description = 'Determines the horizontal size a line of text needs. Does not support line-breaks.',
							functions = {
								{
									arguments = {
										{
											type = 'string',
											name = 'line',
											description = 'A line of text.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'width',
											description = 'The width of the line.'
										}
									}
								}
							}
						},
						{
							name = 'getWrap',
							description = 'Returns how many lines text would be wrapped to. This function accounts for newlines correctly (i.e. \'\\n\')',
							functions = {
								{
									arguments = {
										{
											type = 'string',
											name = 'text',
											description = 'The text that would be wrapped.'
										},
										{
											type = 'number',
											name = 'width',
											description = 'The width to which text should be wrapped.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'width',
											description = 'The actual width the wrapped text.'
										},
										{
											type = 'number',
											name = 'lines',
											description = 'The number of lines text was wrapped to.'
										}
									}
								}
							}
						},
						{
							name = 'setLineHeight',
							description = 'Sets the line height. When rendering the font in lines the actual height will be determined by the line height multiplied by the height of the font. The default is 1.0.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'height',
											description = 'The new line height.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'Image',
					description = 'Drawable image type.',
					constructors = {
						'newImage'
					},
					functions = {
						{
							name = 'getFilter',
							description = 'Gets the filter mode for an image.',
							functions = {
								{
									returns = {
										{
											type = 'FilterMode',
											name = 'min',
											description = 'Filter mode used when minifying the image.'
										},
										{
											type = 'FilterMode',
											name = 'mag',
											description = 'Filter mode used when magnifying the image.'
										}
									}
								}
							}
						},
						{
							name = 'getHeight',
							description = 'Returns the height of the Image.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'h',
											description = 'The height of the Image, in pixels.'
										}
									}
								}
							}
						},
						{
							name = 'getWidth',
							description = 'Returns the width of the Image.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'w',
											description = 'The width of the Image, in pixels.'
										}
									}
								}
							}
						},
						{
							name = 'getWrap',
							description = 'Gets the wrapping properties of an Image.\n\nThis functions returns the currently set horizontal and vertical wrapping modes for the image.',
							functions = {
								{
									returns = {
										{
											type = 'WrapMode',
											name = 'horiz',
											description = 'Horizontal wrapping mode of the image.'
										},
										{
											type = 'WrapMode',
											name = 'vert',
											description = 'Vertical wrapping mode of the image.'
										}
									}
								}
							}
						},
						{
							name = 'setFilter',
							description = 'Sets the filter mode for an image.',
							functions = {
								{
									arguments = {
										{
											type = 'FilterMode',
											name = 'min',
											description = 'How to scale an image down.'
										},
										{
											type = 'FilterMode',
											name = 'mag',
											description = 'How to scale an image up.'
										}
									}
								}
							}
						},
						{
							name = 'setWrap',
							description = 'Sets the wrapping properties of an Image.\n\nThis function sets the way an Image is repeated when it is drawn with a Quad that is larger than the image\'s extent. An image may be clamped or set to repeat in both horizontal and vertical directions. Clamped images appear only once, but repeated ones repeat as many times as there is room in the Quad.\n\nN.B. If you use a Quad that is larger than the image extent and do not use repeated tiling, there may be an unwanted visual effect of the image stretching all the way to fill the Quad. If this is the case, setting Image:getWrap("repeat", "repeat") for all the images to be repeated, and using Quads of appropriate size will result in the best visual appearance.',
							functions = {
								{
									arguments = {
										{
											type = 'WrapMode',
											name = 'horiz',
											description = 'Horizontal wrapping mode of the image.'
										},
										{
											type = 'WrapMode',
											name = 'vert',
											description = 'Vertical wrapping mode of the image.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Drawable',
						'Object'
					}
				},
				{
					name = 'ParticleSystem',
					description = 'Used to create cool effects, like fire. The particle systems are created and drawn on the screen using functions in love.graphics. They also need to be updated in the update(dt) callback for you to see any changes in the particles emitted.',
					constructors = {
						'newParticleSystem'
					},
					functions = {
						{
							name = 'count',
							description = 'Gets the amount of particles that are currently in the system.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'count',
											description = 'The current number of live particles.'
										}
									}
								}
							}
						},
						{
							name = 'getDirection',
							description = 'Gets the direction of the particle emitter (in radians).',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'direction',
											description = 'The direction of the emitter (radians).'
										}
									}
								}
							}
						},
						{
							name = 'getOffsetX',
							description = 'Get the x coordinate of the particle rotation offset.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'xOffset',
											description = 'The x coordinate of the rotation offset.'
										}
									}
								}
							}
						},
						{
							name = 'getOffsetY',
							description = 'Get the y coordinate of the particle rotation offset.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'yOffset',
											description = 'The y coordinate of the rotation offset.'
										}
									}
								}
							}
						},
						{
							name = 'getSpread',
							description = 'Gets the amount of directional spread of the particle emitter (in radians).',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'spread',
											description = 'The spread of the emitter (radians).'
										}
									}
								}
							}
						},
						{
							name = 'getX',
							description = 'Gets the x-coordinate of the particle emitter\'s position.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'Position along x-axis.'
										}
									}
								}
							}
						},
						{
							name = 'getY',
							description = 'Gets the y-coordinate of the particle emitter\'s position.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'y',
											description = 'Position along y-axis.'
										}
									}
								}
							}
						},
						{
							name = 'isActive',
							description = 'Checks whether the particle system is actively emitting particles.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'active',
											description = 'True if system is active, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isEmpty',
							description = 'Checks whether the particle system is empty of particles.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'empty',
											description = 'True if there are no live particles, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isFull',
							description = 'Checks whether the particle system is full of particles.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'full',
											description = 'True if no more particles can be added, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'pause',
							description = 'Pauses the particle emitter.',
							functions = {
								{}
							}
						},
						{
							name = 'reset',
							description = 'Resets the particle emitter, removing any existing particles and resetting the lifetime counter.',
							functions = {
								{}
							}
						},
						{
							name = 'setBufferSize',
							description = 'Sets the size of the buffer (the max allowed amount of particles in the system).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'buffer',
											description = 'The buffer size.'
										}
									}
								}
							}
						},
						{
							name = 'setColors',
							description = 'Sets a series of colors to apply to the particle sprite. The particle system will interpolate between each color evenly over the particle\'s lifetime. Color modulation needs to be activated for this function to have any effect.\n\nArguments are passed in groups of four, representing the components of the desired RGBA value. At least one color must be specified. A maximum of eight may be used.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'r1',
											description = 'First color, red component (0-255).'
										},
										{
											type = 'number',
											name = 'g1',
											description = 'First color, green component (0-255).'
										},
										{
											type = 'number',
											name = 'b1',
											description = 'First color, blue component (0-255).'
										},
										{
											type = 'number',
											name = 'a1',
											description = 'First color, alpha component (0-255).'
										},
										{
											type = 'number',
											name = 'r2',
											description = 'Second color, red component (0-255).'
										},
										{
											type = 'number',
											name = 'g2',
											description = 'Second color, green component (0-255).'
										},
										{
											type = 'number',
											name = 'b2',
											description = 'Second color, blue component (0-255).'
										},
										{
											type = 'number',
											name = 'a2',
											description = 'Second color, alpha component (0-255).'
										},
										{
											type = 'number',
											name = '...',
											description = 'Etc.'
										}
									}
								}
							}
						},
						{
							name = 'setDirection',
							description = 'Sets the direction the particles will be emitted in.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'direction',
											description = 'The direction of the particles (in radians).'
										}
									}
								}
							}
						},
						{
							name = 'setEmissionRate',
							description = 'Sets the amount of particles emitted per second.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'rate',
											description = 'The amount of particles per second.'
										}
									}
								}
							}
						},
						{
							name = 'setGravity',
							description = 'Sets the gravity affecting the particles (acceleration along the y-axis). Every particle created will have a gravity between min and max.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum gravity.'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum gravity.'
										}
									}
								}
							}
						},
						{
							name = 'setLifetime',
							description = 'Sets how long the particle system should emit particles (if -1 then it emits particles forever).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'life',
											description = 'The lifetime of the emitter (in seconds).'
										}
									}
								}
							}
						},
						{
							name = 'setOffset',
							description = 'Set the offset position which the particle sprite is rotated around. If this function is not used, the particles rotate around their center.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x coordinate of the rotation offset.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y coordinate of the rotation offset.'
										}
									}
								}
							}
						},
						{
							name = 'setParticleLife',
							description = 'Sets the life of the particles.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum life of the particles (seconds).'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum life of the particles (seconds).'
										}
									}
								}
							}
						},
						{
							name = 'setPosition',
							description = 'Sets the position of the emitter.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'Position along x-axis.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'Position along y-axis.'
										}
									}
								}
							}
						},
						{
							name = 'setRadialAcceleration',
							description = 'Set the radial acceleration (away from the emitter).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum acceleration.'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum acceleration.'
										}
									}
								}
							}
						},
						{
							name = 'setRotation',
							description = 'Sets the rotation of the image upon particle creation (in radians).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum initial angle (radians).'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum initial angle (radians).'
										}
									}
								}
							}
						},
						{
							name = 'setSizes',
							description = 'Sets a series of sizes by which to scale a particle sprite. 1.0 is normal size. The particle system will interpolate between each size evenly over the particle\'s lifetime.\n\nAt least one size must be specified. A maximum of eight may be used.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'size1',
											description = 'The first size.'
										},
										{
											type = 'number',
											name = 'size2',
											description = 'The second size.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Etc.'
										}
									}
								}
							}
						},
						{
							name = 'setSizeVariation',
							description = 'Sets the degree of variation (0 meaning no variation and 1 meaning full variation between start and end).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'variation',
											description = 'The degree of variation (0 meaning no variation and 1 meaning full variation between start and end).'
										}
									}
								}
							}
						},
						{
							name = 'setSpeed',
							description = 'Sets the speed of the particles.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum linear speed of the particles.'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum linear speed of the particles.'
										}
									}
								}
							}
						},
						{
							name = 'setSpin',
							description = 'Sets the spin of the sprite.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum spin (radians per second).'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum spin (radians per second).'
										},
										{
											type = 'number',
											name = 'variation',
											default = '1',
											description = 'The degree of variation (0 meaning no variation and 1 meaning full variation between start and end).'
										}
									}
								}
							}
						},
						{
							name = 'setSpinVariation',
							description = 'Sets the degree of variation (0 meaning no variation and 1 meaning full variation between start and end).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'variation',
											description = 'The degree of variation (0 meaning no variation and 1 meaning full variation between start and end).'
										}
									}
								}
							}
						},
						{
							name = 'setSpread',
							description = 'Sets the amount of spread for the system.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'spread',
											description = 'The amount of spread (radians).'
										}
									}
								}
							}
						},
						{
							name = 'setSprite',
							description = 'Sets the image which is to be emitted.',
							functions = {
								{
									arguments = {
										{
											type = 'Image',
											name = 'sprite',
											description = 'An Image to use for the particle.'
										}
									}
								}
							}
						},
						{
							name = 'setTangentialAcceleration',
							description = 'Sets the tangential acceleration (acceleration perpendicular to the particle\'s direction).',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'min',
											description = 'The minimum acceleration.'
										},
										{
											type = 'number',
											name = 'max',
											default = 'min',
											description = 'The maximum acceleration.'
										}
									}
								}
							}
						},
						{
							name = 'start',
							description = 'Starts the particle emitter.',
							functions = {
								{}
							}
						},
						{
							name = 'stop',
							description = 'Stops the particle emitter, resetting the lifetime counter.',
							functions = {
								{}
							}
						},
						{
							name = 'update',
							description = 'Updates the particle system; moving, creating and killing particles.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'dt',
											description = 'The time (seconds) since last frame.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Drawable',
						'Object'
					}
				},
				{
					name = 'PixelEffect',
					description = 'A PixelEffect is used for advanced hardware-accelerated pixel manipulation. These effects are written in a language based on GLSL (OpenGL Shading Language) with a few things simplified for easier coding.\n\nPotential uses for pixel effects include HDR/bloom, motion blur, grayscale/invert/sepia/any kind of color effect, reflection/refraction, distortions, and much more!',
					constructors = {
						'newPixelEffect'
					},
					functions = {
						{
							name = 'getWarnings',
							description = 'Returns any warning messages from compiling the pixel effect code. This can be used for debugging your pixel effects if there\'s anything the graphics hardware doesn\'t like.',
							functions = {
								{
									returns = {
										{
											type = 'string',
											name = 'warnings',
											description = 'Warning messages (if any).'
										}
									}
								}
							}
						},
						{
							name = 'send',
							description = 'Sends one or more values to a pixel effect using the specified name.\n\nThis function allows certain aspects of a pixel effect to be controlled by Lua code.',
							functions = {
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'Name of the number to send to the pixel effect.'
										},
										{
											type = 'number',
											name = 'number',
											description = 'Number to send to the pixel effect.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'Name of the vector to send to the pixel effect.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Numbers to send to the pixel effect as a vector. Up to four can be sent. Values can also be packed into a table.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'Name of the vector to send to the pixel effect.'
										},
										{
											type = 'table',
											name = 'values',
											description = 'Numbers to send to the pixel effect as a vector. At least two and up to four can be sent. These values can be accessed inside the shader via a vector.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'Name of the matrix to send to the pixel effect.'
										},
										{
											type = 'table',
											name = 'matrix',
											description = '2x2, 3x3, or 4x4 matrix to send to the pixel effect. Using table form: {{a,b,c,d}, {e,f,g,h}, ... }'
										}
									}
								},
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'Name of the Image to send to the pixel effect.'
										},
										{
											type = 'Image',
											name = 'image',
											description = 'Image to send to the pixel effect for use as extra data.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'Name of the Canvas to send to the pixel effect.'
										},
										{
											type = 'Canvas',
											name = 'canvas',
											description = 'Canvas to send to the pixel effect for use as extra data.'
										}
									}
								},
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'Quad',
					description = 'A quadrilateral with texture coordinate information.\n\nQuads can be used to select part of a texture to draw. In this way, one large Texture Atlas can be loaded, and then split up into sub-images.',
					constructors = {
						'newQuad'
					},
					functions = {
						{
							name = 'flip',
							description = 'Flips this quad horizontally, vertically, or both.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'x',
											description = 'True to flip horizontally, false to leave as-is.'
										},
										{
											type = 'boolean',
											name = 'y',
											description = 'True to flip vertically, false to leave as-is.'
										}
									}
								}
							}
						},
						{
							name = 'getViewport',
							description = 'Gets the current viewport of this Quad.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The top-left corner along the x-axis.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The top-right corner along the y-axis.'
										},
										{
											type = 'number',
											name = 'w',
											description = 'The width of the viewport.'
										},
										{
											type = 'number',
											name = 'h',
											description = 'The height of the viewport.'
										}
									}
								}
							}
						},
						{
							name = 'setViewport',
							description = 'Sets the texture coordinates according to a viewport.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The top-left corner along the x-axis.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The top-right corner along the y-axis.'
										},
										{
											type = 'number',
											name = 'w',
											description = 'The width of the viewport.'
										},
										{
											type = 'number',
											name = 'h',
											description = 'The height of the viewport.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'SpriteBatch',
					description = 'Using a single image, draw any number of identical copies of the image using a single call to love.graphics.draw(). This can be used, for example, to draw repeating copies of a single background image.\n\nA SpriteBatch can be even more useful when the underlying image is a Texture Atlas (a single image file containing many independent images); by adding Quads to the batch, different sub-images from within the atlas can be drawn.',
					constructors = {
						'newSpriteBatch'
					},
					functions = {
						{
							name = 'add',
							description = 'Add a sprite to the batch.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The position to draw the object (x-axis).'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The position to draw the object (y-axis).'
										},
										{
											type = 'number',
											name = 'r',
											default = '0',
											description = 'Orientation (radians).'
										},
										{
											type = 'number',
											name = 'sx',
											default = '1',
											description = 'Scale factor (x-axis).'
										},
										{
											type = 'number',
											name = 'sy',
											default = 'sx',
											description = 'Scale factor (y-axis).'
										},
										{
											type = 'number',
											name = 'ox',
											default = '0',
											description = 'Origin offset (x-axis).'
										},
										{
											type = 'number',
											name = 'oy',
											default = '0',
											description = 'Origin offset (y-axis).'
										}
									}
								}
							}
						},
						{
							name = 'addq',
							description = 'Add a Quad to the batch.',
							functions = {
								{
									returns = {
										{
											type = 'Quad',
											name = 'quad',
											description = 'The Quad to add.'
										},
										{
											type = 'number',
											name = 'x',
											description = 'The position to draw the object (x-axis).'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The position to draw the object (y-axis).'
										},
										{
											type = 'number',
											name = 'r',
											default = '0',
											description = 'Orientation (radians).'
										},
										{
											type = 'number',
											name = 'sx',
											default = '1',
											description = 'Scale factor (x-axis).'
										},
										{
											type = 'number',
											name = 'sy',
											default = 'sx',
											description = 'Scale factor (y-axis).'
										},
										{
											type = 'number',
											name = 'ox',
											default = '0',
											description = 'Origin offset (x-axis).'
										},
										{
											type = 'number',
											name = 'oy',
											default = '0',
											description = 'Origin offset (y-axis).'
										}
									}
								}
							}
						},
						{
							name = 'bind',
							description = 'Binds the SpriteBatch to the memory.\n\nBinding a SpriteBatch before updating its content can improve the performance as it doesn\'t push each update to the graphics card separately. Don\'t forget to unbind the SpriteBatch or the updates won\'t show up.',
							functions = {
								{}
							}
						},
						{
							name = 'clear',
							description = 'Removes all sprites from the buffer.',
							functions = {
								{}
							}
						},
						{
							name = 'setImage',
							description = 'Replaces the image used for the sprites.',
							functions = {
								{
									arguments = {
										{
											type = 'Image',
											name = 'image',
											description = 'The new Image to use for the sprites.'
										}
									}
								}
							}
						},
						{
							name = 'unbind',
							description = 'Unbinds the SpriteBatch.',
							functions = {
								{}
							}
						}
					},
					supertypes = {
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'arc',
					description = 'Draws an arc.',
					functions = {
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the arc.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position of the center along x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position of the center along y-axis.'
								},
								{
									type = 'number',
									name = 'radius',
									description = 'Radius of the arc.'
								},
								{
									type = 'number',
									name = 'angle1',
									description = 'The angle at which the arc begins.'
								},
								{
									type = 'number',
									name = 'angle2',
									description = 'The angle at which the arc terminates.'
								},
								{
									type = 'number',
									name = 'segments',
									default = '10',
									description = 'The number of segments used for drawing the arc.'
								}
							}
						}
					}
				},
				{
					name = 'checkMode',
					description = 'Checks if a display mode is supported.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'width',
									description = 'The display width.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The display height.'
								},
								{
									type = 'boolean',
									name = 'fullscreen',
									description = 'True to check for fullscreen, false for windowed.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'supported',
									description = 'True if supported, false if not.'
								}
							}
						}
					}
				},
				{
					name = 'circle',
					description = 'Draws a circle.',
					functions = {
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the circle.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position of the center along x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position of the center corner along y-axis.'
								},
								{
									type = 'number',
									name = 'radius',
									description = 'The radius of the circle.'
								},
								{
									type = 'number',
									name = 'segments',
									default = '10',
									description = 'The number of segments used for drawing the circle.'
								}
							}
						}
					}
				},
				{
					name = 'clear',
					description = 'Clears the screen to background color.\n\nThis function is called automatically before love.draw in the default love.run function. See the example in love.run for a typical use of this function.\n\nNote that the scissor area bounds the cleared region.',
					functions = {
						{}
					}
				},
				{
					name = 'draw',
					description = 'Draws objects on screen. Drawable objects are loaded images, but may be other kinds of Drawable objects, such as a ParticleSystem.\n\nIn addition to simple drawing, the draw() function can rotate and scale the object at the same time, as well as offset the image (for example, to center the image at the chosen coordinates).\n\nlove.graphics.draw() anchors from the top left corner by default.\n\nYou can specify a negative value for sx or sy to flip the drawable horizontally or vertically.\n\nThe pivotal point is (x, y) on the screen and (ox, oy) in the internal coordinate system of the drawable object, before rotation and scaling. The object is scaled by (sx, sy), then rotated by r around the pivotal point.\n\nThe default ColorMode blends the current drawing color into the image, so you will often want to invoke love.graphics.setColorMode("replace") before drawing images, to ensure that the drawn image matches the source image file.\n\nThe origin offset values are most often used to shift the images up and left by half of its height and width, so that (effectively) the specified x and y coordinates are where the center of the image will end up.',
					functions = {
						{
							arguments = {
								{
									type = 'Drawable',
									name = 'drawable',
									description = 'A drawable object.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position to draw the object (x-axis).'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position to draw the object (y-axis).'
								},
								{
									type = 'number',
									name = 'r',
									default = '0',
									description = 'Orientation (radians).'
								},
								{
									type = 'number',
									name = 'sx',
									default = '1',
									description = 'Scale factor (x-axis). Can be negative.'
								},
								{
									type = 'number',
									name = 'sy',
									default = 'sx',
									description = 'Scale factor (y-axis). Can be negative.'
								},
								{
									type = 'number',
									name = 'ox',
									default = '0',
									description = 'Origin offset (x-axis). (A value of 20 would effectively move your drawable object 20 pixels to the left.)'
								},
								{
									type = 'number',
									name = 'oy',
									default = '0',
									description = 'Origin offset (y-axis). (A value of 20 would effectively move your drawable object 20 pixels up.)'
								},
								{
									type = 'number',
									name = 'kx',
									default = '0',
									description = 'Shearing factor (x-axis).'
								},
								{
									type = 'number',
									name = 'ky',
									default = '0',
									description = 'Shearing factor (y-axis).'
								}
							}
						}
					}
				},
				{
					name = 'drawq',
					description = 'Draw a Quad with the specified Image on screen.',
					functions = {
						{
							arguments = {
								{
									type = 'Image',
									name = 'image',
									description = 'An image to texture the quad with.'
								},
								{
									type = 'Quad',
									name = 'quad',
									description = 'The quad to draw on screen.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position to draw the object (x-axis).'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position to draw the object (y-axis).'
								},
								{
									type = 'number',
									name = 'r',
									default = '0',
									description = 'Orientation (radians).'
								},
								{
									type = 'number',
									name = 'sx',
									default = '1',
									description = 'Scale factor (x-axis). Can be negative.'
								},
								{
									type = 'number',
									name = 'sy',
									default = 'sx',
									description = 'Scale factor (y-axis). Can be negative.'
								},
								{
									type = 'number',
									name = 'ox',
									default = '0',
									description = 'Origin offset (x-axis).'
								},
								{
									type = 'number',
									name = 'oy',
									default = '0',
									description = 'Origin offset (y-axis)'
								},
								{
									type = 'number',
									name = 'kx',
									default = '0',
									description = 'Shearing factor (x-axis).'
								},
								{
									type = 'number',
									name = 'ky',
									default = '0',
									description = 'Shearing factor (y-axis).'
								}
							}
						}
					}
				},
				{
					name = 'getBackgroundColor',
					description = 'Gets the current background color.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'r',
									description = 'The red component (0-255).'
								},
								{
									type = 'number',
									name = 'g',
									description = 'The green component (0-255).'
								},
								{
									type = 'number',
									name = 'b',
									description = 'The blue component (0-255).'
								},
								{
									type = 'number',
									name = 'a',
									description = 'The alpha component (0-255).'
								}
							}
						}
					}
				},
				{
					name = 'getBlendMode',
					description = 'Gets the blending mode.',
					functions = {
						{
							returns = {
								{
									type = 'BlendMode',
									name = 'mode',
									description = 'The current blend mode.'
								}
							}
						}
					}
				},
				{
					name = 'getCanvas',
					description = 'Gets the current target Canvas.',
					functions = {
						{
							returns = {
								{
									type = 'Canvas',
									name = 'canvas',
									description = 'The Canvas set by setCanvas. Returns nil if drawing to the real screen.'
								}
							}
						}
					}
				},
				{
					name = 'getCaption',
					description = 'Gets the window caption.',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'caption',
									description = 'The current window caption.'
								}
							}
						}
					}
				},
				{
					name = 'getColor',
					description = 'Gets the current color.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'r',
									description = 'The red component (0-255).'
								},
								{
									type = 'number',
									name = 'g',
									description = 'The red component (0-255).'
								},
								{
									type = 'number',
									name = 'b',
									description = 'The blue component (0-255).'
								},
								{
									type = 'number',
									name = 'a',
									description = 'The alpha component (0-255).'
								}
							}
						}
					}
				},
				{
					name = 'getColorMode',
					description = 'Gets the color mode (which controls how images are affected by the current color).',
					functions = {
						{
							returns = {
								{
									type = 'ColorMode',
									name = 'mode',
									description = 'The current color mode.'
								}
							}
						}
					}
				},
				{
					name = 'getDefaultImageFilter',
					description = 'Returns the default scaling filters.',
					functions = {
						{
							returns = {
								{
									type = 'FilterMode',
									name = 'min',
									description = 'Filter mode used when scaling the image down.'
								},
								{
									type = 'FilterMode',
									name = 'mag',
									description = 'Filter mode used when scaling the image up.'
								}
							}
						}
					}
				},
				{
					name = 'getFont',
					description = 'Gets the current Font object.',
					functions = {
						{
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'The current Font, or nil of none is set.'
								}
							}
						}
					}
				},
				{
					name = 'getHeight',
					description = 'Gets the height of the window.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'height',
									description = 'The height of the window.'
								}
							}
						}
					}
				},
				{
					name = 'getLineStipple',
					description = 'Gets the current line stipple.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'pattern',
									description = 'The 16-bit stipple pattern.'
								},
								{
									type = 'number',
									name = 'repeat',
									description = 'The repeat factor.'
								}
							}
						}
					}
				},
				{
					name = 'getLineStyle',
					description = 'Gets the line style.',
					functions = {
						{
							returns = {
								{
									type = 'LineStyle',
									name = 'style',
									description = 'The current line style.'
								}
							}
						}
					}
				},
				{
					name = 'getLineWidth',
					description = 'Gets the current line width.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'width',
									description = 'The current line width.'
								}
							}
						}
					}
				},
				{
					name = 'getMaxPointSize',
					description = 'Gets the max supported point size.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'size',
									description = 'The max supported point size.'
								}
							}
						}
					}
				},
				{
					name = 'getMode',
					description = 'Returns the current display mode.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'width',
									description = 'Display width.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'Display height.'
								},
								{
									type = 'boolean',
									name = 'fullscreen',
									description = 'Fullscreen (true) or windowed (false).'
								},
								{
									type = 'boolean',
									name = 'vsync',
									description = 'True if vertical sync is enabled or false if disabled.'
								},
								{
									type = 'number',
									name = 'fsaa',
									description = 'The number of FSAA samples.'
								}
							}
						}
					}
				},
				{
					name = 'getModes',
					description = 'Gets a list of supported fullscreen modes.',
					functions = {
						{
							returns = {
								{
									type = 'table',
									name = 'modes',
									description = 'A table of width/height pairs. (Note that this may not be in order.)'
								}
							}
						}
					}
				},
				{
					name = 'getPixelEffect',
					description = 'Returns the current PixelEffect. Returns nil if none is set.',
					functions = {
						{
							returns = {
								{
									type = 'PixelEffect',
									name = 'pixeleffect',
									description = 'The current PixelEffect.'
								}
							}
						}
					}
				},
				{
					name = 'getPointSize',
					description = 'Gets the point size.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'size',
									description = 'The current point size.'
								}
							}
						}
					}
				},
				{
					name = 'getPointStyle',
					description = 'Gets the current point style.',
					functions = {
						{
							returns = {
								{
									type = 'PointStyle',
									name = 'style',
									description = 'The current point style.'
								}
							}
						}
					}
				},
				{
					name = 'getScissor',
					description = 'Gets the current scissor box.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'x',
									description = 'The x-component of the top-left point of the box.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y-component of the top-left point of the box.'
								},
								{
									type = 'number',
									name = 'width',
									description = 'The width of the box.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The height of the box.'
								}
							}
						}
					}
				},
				{
					name = 'getWidth',
					description = 'Gets the width of the window.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'width',
									description = 'The width of the window.'
								}
							}
						}
					}
				},
				{
					name = 'hasFocus',
					description = 'Checks if the game window has keyboard focus.',
					functions = {
						{
							returns = {
								{
									type = 'boolean',
									name = 'focus',
									description = 'True if the window has the focus or false if not.'
								}
							}
						}
					}
				},
				{
					name = 'isCreated',
					description = 'Checks if the window has been created.',
					functions = {
						{
							returns = {
								{
									type = 'boolean',
									name = 'created',
									description = 'True if the window has been created, false otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'isSupported',
					description = 'Checks if certain graphics functions can be used.\n\nOlder and low-end systems do not always support all graphics extensions.',
					functions = {
						{
							arguments = {
								{
									type = 'GraphicsFeature',
									name = 'supportN',
									description = 'The graphics feature to check for.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'isSupported',
									description = 'True if everything is supported, false otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'line',
					description = 'Draws lines between points.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'x1',
									description = 'The position of first point on the x-axis.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The position of first point on the y-axis.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The position of second point on the x-axis.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The position of second point on the y-axis.'
								},
								{
									type = 'number',
									name = '...',
									description = 'You can continue passing point positions to draw a polyline.'
								}
							}
						}
					}
				},
				{
					name = 'newCanvas',
					description = 'Creates a new Canvas object for offscreen rendering.',
					functions = {
						{
							returns = {
								{
									type = 'Canvas',
									name = 'canvas',
									description = 'A new Canvas with width/height equal to the window width/height.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'number',
									name = 'width',
									description = 'The desired width of the Canvas.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The desired height of the Canvas.'
								}
							},
							returns = {
								{
									type = 'Canvas',
									name = 'canvas',
									description = 'A new Canvas with specified width and height.'
								}
							}
						}
					}
				},
				{
					name = 'newFont',
					description = 'Creates a new Font.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The filepath to the font file.'
								},
								{
									type = 'number',
									name = 'size',
									default = '12',
									description = 'The size of the font in pixels.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'A Font object which can be used to draw text on screen.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'number',
									name = 'size',
									default = '12',
									description = 'The size of the font in pixels.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'A Font object which can be used to draw text on screen.'
								}
							}
						}
					}
				},
				{
					name = 'newImage',
					description = 'Creates a new Image from a filepath or an opened File or an ImageData.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The filepath to the image file.'
								}
							},
							returns = {
								{
									type = 'Image',
									name = 'image',
									description = 'An Image object which can be drawn on screen.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'File',
									name = 'file',
									description = 'A File pointing to an image.'
								}
							},
							returns = {
								{
									type = 'Image',
									name = 'image',
									description = 'An Image object which can be drawn on screen.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'ImageData',
									name = 'imageData',
									description = 'An ImageData object.'
								}
							},
							returns = {
								{
									type = 'Image',
									name = 'image',
									description = 'An Image object which can be drawn on screen.'
								}
							}
						}
					}
				},
				{
					name = 'newImageFont',
					description = 'Creates a new font by loading a specifically formatted image. There can be up to 256 glyphs.',
					functions = {
						{
							arguments = {
								{
									type = 'Image',
									name = 'image',
									description = 'The Image object to create the font from.'
								},
								{
									type = 'string',
									name = 'glyphs',
									description = 'A string of the characters in the image in order from left to right.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'A Font object which can be used to draw text on screen.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The filepath to the image file.'
								},
								{
									type = 'string',
									name = 'glyphs',
									description = 'A string of the characters in the image in order from left to right.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'A Font object which can be used to draw text on screen.'
								}
							}
						}
					}
				},
				{
					name = 'newParticleSystem',
					description = 'Creates a new ParticleSystem.',
					functions = {
						{
							arguments = {
								{
									type = 'Image',
									name = 'image',
									description = 'The image object.'
								},
								{
									type = 'number',
									name = 'buffer',
									description = 'The max number of particles at the same time.'
								}
							},
							returns = {
								{
									type = 'ParticleSystem',
									name = 'system',
									description = 'A new ParticleSystem.'
								}
							}
						}
					}
				},
				{
					name = 'newPixelEffect',
					description = 'Creates a new PixelEffect object for hardware-accelerated pixel level effects.\n\nA PixelEffect contains at least one function, named effect, which is the effect itself, but it can contain additional functions.\n\nvec4 effect( vec4 color, sampler2D texture, vec2 texture_coords, vec2 pixel_coords )',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'code',
									description = 'The pixel effect code.'
								}
							},
							returns = {
								{
									type = 'PixelEffect',
									name = 'pixeleffect',
									description = 'A PixelEffect object for use in drawing operations.'
								}
							}
						}
					}
				},
				{
					name = 'newQuad',
					description = 'Creates a new Quad.\n\nThe purpose of a Quad is to describe the result of the following transformation on any drawable object. The object is first scaled to dimensions sw * sh. The Quad then describes the rectangular area of dimensions width * height whose upper left corner is at position (x, y) inside the scaled object.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'x',
									description = 'The top-left position along the x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The top-left position along the y-axis.'
								},
								{
									type = 'number',
									name = 'width',
									description = 'The width of the Quad. (Must be greater than 0.)'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The height of the Quad. (Must be greater than 0.)'
								},
								{
									type = 'number',
									name = 'sw',
									description = 'The reference width, the width of the Image. (Must be greater than 0.)'
								},
								{
									type = 'number',
									name = 'sh',
									description = 'The reference height, the height of the Image. (Must be greater than 0.)'
								}
							},
							returns = {
								{
									type = 'Quad',
									name = 'quad',
									description = 'The new Quad.'
								}
							}
						}
					}
				},
				{
					name = 'newScreenshot',
					description = 'Creates a screenshot and returns the image data.',
					functions = {
						{
							returns = {
								{
									type = 'ImageData',
									name = 'screenshot',
									description = 'The image data of the screenshot.'
								}
							}
						}
					}
				},
				{
					name = 'newSpriteBatch',
					description = 'Creates a new SpriteBatch object.',
					functions = {
						{
							arguments = {
								{
									type = 'Image',
									name = 'image',
									description = 'The Image to use for the sprites.'
								},
								{
									type = 'number',
									name = 'size',
									default = '1000',
									description = 'The max number of sprites.'
								}
							},
							returns = {
								{
									type = 'SpriteBatch',
									name = 'spriteBatch',
									description = 'The new SpriteBatch.'
								}
							}
						}
					}
				},
				{
					name = 'newStencil',
					description = 'Creates a new stencil.',
					functions = {
						{
							arguments = {
								{
									type = 'function',
									name = 'stencilFunction',
									description = 'Function that draws the stencil.'
								}
							},
							returns = {
								{
									type = 'function',
									name = 'myStencil',
									description = 'Function that defines the new stencil.'
								}
							}
						}
					}
				},
				{
					name = 'point',
					description = 'Draws a point.\n\nThe pixel grid is actually offset to the center of each pixel. So to get clean pixels drawn use 0.5 + integer increments.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'x',
									description = 'The position on the x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position on the y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'polygon',
					description = 'Draw a polygon.\n\nFollowing the mode argument, this function can accept multiple numeric arguments or a single table of numeric arguments. In either case the arguments are interpreted as alternating x and y coordinates of the polygon\'s vertices.\n\nWhen in fill mode, the polygon must be convex and simple or rendering artifacts may occur.',
					functions = {
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the polygon.'
								},
								{
									type = 'number',
									name = '...',
									description = 'The vertices of the polygon.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the polygon.'
								},
								{
									type = 'table',
									name = 'vertices',
									description = 'The vertices of the polygon as a table.'
								}
							}
						}
					}
				},
				{
					name = 'pop',
					description = 'Pops the current coordinate transformation from the transformation stack.\n\nThis function is always used to reverse a previous push operation. It returns the current transformation state to what it was before the last preceding push. For an example, see the description of love.graphics.push.',
					functions = {
						{}
					}
				},
				{
					name = 'present',
					description = 'Displays the results of drawing operations on the screen.\n\nThis function is used when writing your own love.run function. It presents all the results of your drawing operations on the screen. See the example in love.run for a typical use of this function.',
					functions = {
						{}
					}
				},
				{
					name = 'print',
					description = 'Draws text on screen. If no Font is set, one will be created and set (once) if needed.\n\nAs of LVE 0.7.1, when using translation and scaling functions while drawing text, this function assumes the scale occurs first. If you don\'t script with this in mind, the text won\'t be in the right position, or possibly even on screen.\n\nDrawing uses the current color, but only if the ColorMode is "modulate" (which is the default). If your text is displayed as white, it is probably because the color mode is "replace" (which is useful when drawing sprites). Change the color model to "modulate" before drawing.\n\nlove.graphics.print stops at the first \'\0\' (null) character. This can bite you if you are appending keystrokes to form your string, as some of those are multi-byte unicode characters which will likely contain null bytes.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'text',
									description = 'The text to draw.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position to draw the object (x-axis).'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position to draw the object (y-axis).'
								},
								{
									type = 'number',
									name = 'r',
									default = '0',
									description = 'Orientation (radians).'
								},
								{
									type = 'number',
									name = 'sx',
									default = '1',
									description = 'Scale factor (x-axis).'
								},
								{
									type = 'number',
									name = 'sy',
									default = 'sx',
									description = 'Scale factor (y-axis).'
								},
								{
									type = 'number',
									name = 'ox',
									default = '0',
									description = 'Origin offset (x-axis).'
								},
								{
									type = 'number',
									name = 'oy',
									default = '0',
									description = 'Origin offset (y-axis).'
								},
								{
									type = 'number',
									name = 'kx',
									default = '0',
									description = 'Shear factor (x-axis).'
								},
								{
									type = 'number',
									name = 'ky',
									default = '0',
									description = 'Shear factor (y-axis).'
								}
							}
						}
					}
				},
				{
					name = 'printf',
					description = 'Draws formatted text, with word wrap and alignment.\n\nSee additional notes in love.graphics.print.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'text',
									description = 'A text string.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position on the x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position on the y-axis.'
								},
								{
									type = 'number',
									name = 'limit',
									description = 'Wrap the line after this many horizontal pixels.'
								},
								{
									type = 'AlignMode',
									name = 'align',
									default = '"left"',
									description = 'The alignment.'
								}
							}
						}
					}
				},
				{
					name = 'push',
					description = 'Copies and pushes the current coordinate transformation to the transformation stack.\n\nThis function is always used to prepare for a corresponding pop operation later. It stores the current coordinate transformation state into the transformation stack and keeps it active. Later changes to the transformation can be undone by using the pop operation, which returns the coordinate transform to the state it was in before calling push.',
					functions = {
						{}
					}
				},
				{
					name = 'quad',
					description = 'Draws a quadrilateral shape.',
					functions = {
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the quad.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The position of the top left corner along x-axis.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The position of the top left corner along y-axis.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The position of the top right corner along x-axis.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The position of the top right corner along y-axis.'
								},
								{
									type = 'number',
									name = 'x3',
									description = 'The position of the bottom right corner along x-axis.'
								},
								{
									type = 'number',
									name = 'y3',
									description = 'The position of the bottom right corner along y-axis.'
								},
								{
									type = 'number',
									name = 'x4',
									description = 'The position of the bottom left corner along x-axis.'
								},
								{
									type = 'number',
									name = 'y4',
									description = 'The position of the bottom left corner along y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'rectangle',
					description = 'Draws a rectangle.',
					functions = {
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the rectangle.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The position of top-left corner along x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position of top-left corner along y-axis.'
								},
								{
									type = 'number',
									name = 'width',
									description = 'Width of the rectangle.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'Height of the rectangle.'
								}
							}
						}
					}
				},
				{
					name = 'reset',
					description = 'Resets the current graphics settings.\n\nCalling reset makes the current drawing color white, the current background color black, the window title empty and removes any scissor settings. It sets the BlendMode to alpha and ColorMode to modulate. It also sets both the point and line drawing modes to smooth and their sizes to 1.0 . Finally, it removes any stipple settings.',
					functions = {
						{}
					}
				},
				{
					name = 'rotate',
					description = 'Rotates the coordinate system in two dimensions.\n\nCalling this function affects all future drawing operations by rotating the coordinate system around the origin by the given amount of radians. This change lasts until love.draw() exits.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'angle',
									description = 'The amount to rotate the coordinate system in radians.'
								}
							}
						}
					}
				},
				{
					name = 'scale',
					description = 'Scales the coordinate system in two dimensions.\n\nBy default the coordinate system in LVE corresponds to the display pixels in horizontal and vertical directions one-to-one, and the x-axis increases towards the right while the y-axis increases downwards. Scaling the coordinate system changes this relation.\n\nAfter scaling by sx and sy, all coordinates are treated as if they were multiplied by sx and sy. Every result of a drawing operation is also correspondingly scaled, so scaling by (2, 2) for example would mean making everything twice as large in both x- and y-directions. Scaling by a negative value flips the coordinate system in the corresponding direction, which also means everything will be drawn flipped or upside down, or both. Scaling by zero is not a useful operation.\n\nScale and translate are not commutative operations, therefore, calling them in different orders will change the outcome.\n\nScaling lasts until love.draw() exits.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'sx',
									description = 'The scaling in the direction of the x-axis.'
								},
								{
									type = 'number',
									name = 'sy',
									default = 'sx',
									description = 'The scaling in the direction of the y-axis. If omitted, it defaults to same as parameter sx.'
								}
							}
						}
					}
				},
				{
					name = 'setBackgroundColor',
					description = 'Sets the background color.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'r',
									description = 'The red component (0-255).'
								},
								{
									type = 'number',
									name = 'g',
									description = 'The green component (0-255).'
								},
								{
									type = 'number',
									name = 'b',
									description = 'The blue component (0-255).'
								}
							}
						},
						{
							arguments = {
								{
									type = 'number',
									name = 'r',
									description = 'The red component (0-255).'
								},
								{
									type = 'number',
									name = 'g',
									description = 'The green component (0-255).'
								},
								{
									type = 'number',
									name = 'b',
									description = 'The blue component (0-255).'
								},
								{
									type = 'number',
									name = 'a',
									description = 'The alpha component (0-255).'
								}
							}
						},
						{
							arguments = {
								{
									type = 'table',
									name = 'rgb',
									description = 'A numerical indexed table with the red, green and blue values as numbers.'
								}
							}
						}
					}
				},
				{
					name = 'setBlendMode',
					description = 'Sets the blending mode.',
					functions = {
						{
							arguments = {
								{
									type = 'BlendMode',
									name = 'mode',
									description = 'The blend mode to use.'
								}
							}
						}
					}
				},
				{
					name = 'setCanvas',
					description = 'Captures drawing operations to a Canvas',
					functions = {
						{
							notes = 'Sets the render target to a specified Canvas. All drawing operations until the next love.graphics.setCanvas call will be redirected to the Canvas and not shown on the screen.',
							arguments = {
								{
									type = 'Canvas',
									name = 'canvas',
									description = 'The Canvas set by setCanvas. Returns nil if drawing to the real screen.'
								}
							}
						},
						{
							notes = 'Resets the render target to the screen, i.e. re-enables drawing to the screen.',
						}
					}
				},
				{
					name = 'setCaption',
					description = 'Sets the window caption.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'caption',
									description = 'The new window caption.'
								}
							}
						}
					}
				},
				{
					name = 'setColor',
					description = 'Sets the color used for drawing.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'red',
									description = 'The amount of red.'
								},
								{
									type = 'number',
									name = 'green',
									description = 'The amount of green.'
								},
								{
									type = 'number',
									name = 'blue',
									description = 'The amount of blue.'
								},
								{
									type = 'number',
									name = 'alpha',
									description = 'The amount of alpha. The alpha value will be applied to all subsequent draw operations, even the drawing of an image.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'table',
									name = 'rgba',
									description = 'A numerical indexed table with the red, green, blue and alpha values as numbers. The alpha is optional and defaults to 255 if it is left out.'
								}
							}
						}
					}
				},
				{
					name = 'setColorMode',
					description = 'Sets the color mode (which controls how images are affected by the current color).',
					functions = {
						{
							arguments = {
								{
									type = 'ColorMode',
									name = 'mode',
									description = 'The color mode to use.'
								}
							}
						}
					}
				},
				{
					name = 'setDefaultImageFilter',
					description = 'Sets the default scaling filters.',
					functions = {
						{
							arguments = {
								{
									type = 'FilterMode',
									name = 'min',
									description = 'Filter mode used when scaling the image down.'
								},
								{
									type = 'FilterMode',
									name = 'mag',
									description = 'Filter mode used when scaling the image up.'
								}
							}
						}
					}
				},
				{
					name = 'setFont',
					description = 'Set an already-loaded Font as the current font or create and load a new one from the file and size.\n\nIt\'s recommended that Font objects are created with love.graphics.newFont in the loading stage and then passed to this function in the drawing stage.',
					functions = {
						{
							arguments = {
								{
									type = 'Font',
									name = 'font',
									description = 'The Font object to use.'
								}
							}
						}
					}
				},
				{
					name = 'setIcon',
					description = 'Set window icon. This feature is not completely supported on Windows (apparently an SDL bug, not a LVE bug).\n\nThe icon should be a 32x32px png image.',
					functions = {
						{
							arguments = {
								{
									type = 'Drawable',
									name = 'drawable',
									description = 'A drawable object.'
								}
							}
						}
					}
				},
				{
					name = 'setInvertedStencil',
					description = 'Defines an inverted stencil for the drawing operations or releases the active one.\n\nIt\'s the same as love.graphics.setStencil with the mask inverted.',
					functions = {
						{
							arguments = {
								{
									type = 'function',
									name = 'stencilFunction',
									description = 'Function that draws the stencil.'
								}
							}
						},
						{
							notes = 'Releases the active stencil.'
						}
					}
				},
				{
					name = 'setLine',
					description = 'Sets the line width and style.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'width',
									description = 'The width of the line.'
								},
								{
									type = 'LineStyle',
									name = 'style',
									default = '"smooth"',
									description = 'The LineStyle to use.'
								}
							}
						}
					}
				},
				{
					name = 'setLineStipple',
					description = 'Sets the line stipple pattern.\n\nA stipple pattern is made up of a 16bit sequence of 0s and 1s, Just like binary.\n\nThe pattern is repeated to complete the line. Using the repeat will stretch the pattern and multiplies each 1 and 0. For example if three 1s are consecutively placed they are stretched to six if the repeat is 2. The maximum repeat is 255, and the minimum repeat is 1.\n\nA 1 is a a cue to draw a pixel whereas 0 is the opposite and does not draw a pixel, This is done per pixel for the given line.\n\nA pattern is read from back to front.\n\n0x3F07 would equal to 0011111100000111 in binary.\n\nYou can visualise the pattern by reading the binary sequence backwards.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'pattern',
									description = 'A 16-bit pattern.'
								},
								{
									type = 'number',
									name = 'repeat',
									description = 'Repeat factor.'
								}
							}
						}
					}
				},
				{
					name = 'setLineStyle',
					description = 'Sets the line style.',
					functions = {
						{
							arguments = {
								{
									type = 'LineStyle',
									name = 'style',
									description = 'The LineStyle to use.'
								}
							}
						}
					}
				},
				{
					name = 'setLineWidth',
					description = 'Sets the line width.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'width',
									description = 'The width of the line.'
								}
							}
						}
					}
				},
				{
					name = 'setMode',
					description = 'Changes the display mode.\n\nIf width and height are both 0, setMode will use the resolution of the desktop.\n\nUnsets certain settings on images, like WrapMode.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'width',
									description = 'Display width.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'Display height.'
								},
								{
									type = 'boolean',
									name = 'fullscreen',
									description = 'Fullscreen (true) or windowed (false).'
								},
								{
									type = 'boolean',
									name = 'vsync',
									description = 'True if LVE should wait for vsync, false otherwise.'
								},
								{
									type = 'number',
									name = 'fsaa',
									description = 'The number of FSAA-buffers.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'success',
									description = 'True if successful, false otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'setNewFont',
					description = 'Creates and sets a new font.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'Creates and sets a new font.'
								},
								{
									type = 'number',
									name = 'size',
									default = '12',
									description = 'The size of the font.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'The new font.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'File',
									name = 'file',
									description = 'A File with the font.'
								},
								{
									type = 'number',
									name = 'size',
									default = '12',
									description = 'The size of the font.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'The new font.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'Data',
									name = 'file',
									description = 'A Data with the font.'
								},
								{
									type = 'number',
									name = 'size',
									default = '12',
									description = 'The size of the font.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'The new font.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'Rasterizer',
									name = 'file',
									description = 'A rasterizer.'
								}
							},
							returns = {
								{
									type = 'Font',
									name = 'font',
									description = 'The new font.'
								}
							}
						}
					}
				},
				{
					name = 'setPixelEffect',
					description = 'Sets or resets a PixelEffect as the current pixel effect. All drawing operations until the next love.graphics.setPixelEffect will be drawn using the PixelEffect object specified.',
					functions = {
						{
							notes = 'Sets the current pixel shader to a specified PixelEffect. All drawing operations until the next love.graphics.setPixelEffect will be drawn using the PixelEffect object specified.',
							arguments = {
								{
									type = 'PixelEffect',
									name = 'pixeleffect',
									description = 'The new pixel effect.'
								}
							}
						},
						{
							notes = 'Disables pixel effects, allowing unfiltered drawing operations.'
						}
					}
				},
				{
					name = 'setPoint',
					description = 'Sets the point size and style.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'size',
									description = 'The new point size.'
								},
								{
									type = 'PointStyle',
									name = 'style',
									description = 'The new point style.'
								}
							}
						}
					}
				},
				{
					name = 'setPointSize',
					description = 'Sets the point size.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'size',
									description = 'The new point size.'
								}
							}
						}
					}
				},
				{
					name = 'setPointStyle',
					description = 'Sets the point style.',
					functions = {
						{
							arguments = {
								{
									type = 'PointStyle',
									name = 'style',
									description = 'The new point style.'
								}
							}
						}
					}
				},
				{
					name = 'setScissor',
					description = 'Sets or disables scissor.\n\nThe scissor limits the drawing area to a specified rectangle. This affects all graphics calls, including love.graphics.clear.',
					functions = {
						{},
						{
							arguments = {
								{
									type = 'number',
									name = 'x',
									description = 'The X coordinate of upper left corner.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The Y coordinate of upper left corner.'
								},
								{
									type = 'number',
									name = 'width',
									description = 'The width of clipping rectangle.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The height of clipping rectangle.'
								}
							}
						}
					}
				},
				{
					name = 'setStencil',
					description = 'Defines or releases a stencil for the drawing operations.\n\nThe passed function draws to the stencil instead of the screen, creating an image with transparent and opaque pixel. While active, it is used to test where pixel will be drawn or discarded.\n\nCalling the function without arguments releases the active stencil.',
					functions = {
						{
							arguments = {
								{
									type = 'function',
									name = 'stencilFunction',
									description = 'Function that draws the stencil.'
								}
							}
						},
						{
							notes = 'Releases the active stencil.'
						}
					}
				},
				{
					name = 'shear',
					description = 'Shears the coordinate system.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'kx',
									description = 'The shear factor on the x-axis.'
								},
								{
									type = 'number',
									name = 'ky',
									description = 'The shear factor on the y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'toggleFullscreen',
					description = 'Toggles fullscreen.',
					functions = {
						{
							returns = {
								{
									type = 'boolean',
									name = 'success',
									description = 'True if successful, false otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'translate',
					description = 'Translates the coordinate system in two dimensions.\n\nWhen this function is called with two numbers, dx, and dy, all the following drawing operations take effect as if their x and y coordinates were x+dx and y+dy.\n\nScale and translate are not commutative operations, therefore, calling them in different orders will change the outcome.\n\nThis change lasts until love.draw() exits or else a love.graphics.pop reverts to a previous love.graphics.push.\n\nTranslating using whole numbers will prevent tearing/blurring of images and fonts draw after translating.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'dx',
									description = 'The translation relative to the x-axis.'
								},
								{
									type = 'number',
									name = 'dy',
									description = 'The translation relative to the y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'triangle',
					description = 'Draws a triangle.',
					functions = {
						{
							arguments = {
								{
									type = 'DrawMode',
									name = 'mode',
									description = 'How to draw the triangle.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The position of first point on the x-axis.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The position of first point on the y-axis.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The position of second point on the x-axis.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The position of second point on the y-axis.'
								},
								{
									type = 'number',
									name = 'x3',
									description = 'The position of third point on the x-axis.'
								},
								{
									type = 'number',
									name = 'y3',
									description = 'The position of third point on the y-axis.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'AlignMode',
					description = 'Text alignment.',
					constants = {
						{
							name = 'center',
							description = 'Align text center.'
						},
						{
							name = 'left',
							description = 'Align text left.'
						},
						{
							name = 'right',
							description = 'Align text right.'
						}
					}
				},
				{
					name = 'BlendMode',
					description = 'Different ways you do alpha blending.',
					constants = {
						{
							name = 'additive',
							description = 'Additive blend mode.'
						},
						{
							name = 'alpha',
							description = 'Alpha blend mode ("normal").'
						},
						{
							name = 'subtractive',
							description = 'Subtractive blend mode.'
						},
						{
							name = 'multiplicative',
							description = 'Multiply blend mode.'
						},
						{
							name = 'premultiplied',
							description = 'Premultiplied blend mode.'
						}
					}
				},
				{
					name = 'ColorMode',
					description = 'Controls whether images will be affected by the current color.',
					constants = {
						{
							name = 'modulate',
							description = 'Images (etc) will be affected by the current color.'
						},
						{
							name = 'replace',
							description = 'Replace color mode. Images (etc) will not be affected by current color.'
						}
					}
				},
				{
					name = 'DrawMode',
					description = 'Controls whether shapes are drawn as an outline, or filled.',
					constants = {
						{
							name = 'fill',
							description = 'Draw filled shape.'
						},
						{
							name = 'line',
							description = 'Draw outlined shape.'
						}
					}
				},
				{
					name = 'FilterMode',
					description = 'How the image is filtered when scaling.',
					constants = {
						{
							name = 'linear',
							description = 'Scale image with linear interpolation.'
						},
						{
							name = 'nearest',
							description = 'Scale image with nearest neighbor interpolation.'
						}
					}
				},
				{
					name = 'BlendMode',
					description = 'Graphics features that can be checked for with love.graphics.isSupported.',
					constants = {
						{
							name = 'canvas',
							description = 'Support for Canvas.'
						},
						{
							name = 'pixeleffect',
							description = 'Support for PixelEffect.'
						},
						{
							name = 'npot',
							description = 'Support for textures with non-power-of-two textures. See PO2 Syndrome.'
						},
						{
							name = 'subtractive',
							description = 'Support for the subtractive blend mode.'
						}
					}
				},
				{
					name = 'LineStyle',
					description = 'The styles in which lines are drawn.',
					constants = {
						{
							name = 'rough',
							description = 'Draw rough lines.'
						},
						{
							name = 'smooth',
							description = 'Draw smooth lines.'
						}
					}
				},
				{
					name = 'PointStyle',
					description = 'How points should be drawn.',
					constants = {
						{
							name = 'rough',
							description = 'Draw rough points.'
						},
						{
							name = 'smooth',
							description = 'Draw smooth points.'
						}
					}
				},
				{
					name = 'WrapMode',
					description = 'How the image wraps inside a large Quad.',
					constants = {
						{
							name = 'clamp',
							description = 'Clamp the image. Appears only once.'
						},
						{
							name = 'repeat',
							description = 'Repeat the image. Fills the whole available extent.'
						}
					}
				}
			}
		},
		{
			name = 'image',
			description = 'Provides an interface to decode encoded image data.',
			types = {
				{
					name = 'ImageData',
					description = 'Raw (decoded) image data.\n\nYou can\'t draw ImageData directly to screen. See Image for that.',
					constructors = {
						'newImageData'
					},
					functions = {
						{
							name = 'encode',
							description = 'Encodes the ImageData.',
							functions = {
								{
									arguments = {
										{
											type = 'string',
											name = 'outFile',
											description = 'Name of a file to write encoded data to. The format will be automatically deduced from the file extension.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'string',
											name = 'outFile',
											description = 'Name of a file to write encoded data to.'
										},
										{
											type = 'ImageFormat',
											name = 'format',
											description = 'The format to encode the image in.'
										}
									}
								}
							}
						},
						{
							name = 'getHeight',
							description = 'Gets the height of the ImageData.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'height',
											description = 'The the height of the ImageData.'
										}
									}
								}
							}
						},
						{
							name = 'getPixel',
							description = 'Gets the pixel at the specified position.\n\nValid x and y values start at 0 and go up to image width and height minus 1.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The position of the pixel on the x-axis.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The position of the pixel on the y-axis.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'r',
											description = 'The red component (0-255).'
										},
										{
											type = 'number',
											name = 'g',
											description = 'The green component (0-255).'
										},
										{
											type = 'number',
											name = 'b',
											description = 'The blue component (0-255).'
										},
										{
											type = 'number',
											name = 'a',
											description = 'The alpha component (0-255).'
										}
									}
								}
							}
						},
						{
							name = 'getString',
							description = 'Gets the full ImageData as a string.',
							functions = {
								{
									returns = {
										{
											type = 'string',
											name = 'pixels',
											description = 'The raw data.'
										}
									}
								}
							}
						},
						{
							name = 'getWidth',
							description = 'Gets the width of the ImageData.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'width',
											description = 'The width of the ImageData.'
										}
									}
								}
							}
						},
						{
							name = 'mapPixel',
							description = 'Transform an image by applying a function to every pixel.\n\nThis function is a higher order function. It takes another function as a parameter, and calls it once for each pixel in the ImageData.\n\nThe function parameter is called with six parameters for each pixel in turn. The parameters are numbers that represent the x and y coordinates of the pixel and its red, green, blue and alpha values. The function parameter can return up to four number values, which become the new r, g, b and a values of the pixel. If the function returns fewer values, the remaining components are set to 0.',
							functions = {
								{
									arguments = {
										{
											type = 'function',
											name = 'pixelFunction',
											description = 'Function parameter to apply to every pixel.'
										}
									}
								}
							}
						},
						{
							name = 'paste',
							description = 'Paste into ImageData from another source ImageData.',
							functions = {
								{
									arguments = {
										{
											type = 'ImageData',
											name = 'source',
											description = 'Source ImageData from which to copy.'
										},
										{
											type = 'number',
											name = 'dx',
											description = 'Destination top-left position on x-axis.'
										},
										{
											type = 'number',
											name = 'dy',
											description = 'Destination top-left position on y-axis.'
										},
										{
											type = 'number',
											name = 'sx',
											description = 'Source top-left position on x-axis.'
										},
										{
											type = 'number',
											name = 'sy',
											description = 'Source top-left position on y-axis.'
										},
										{
											type = 'number',
											name = 'sw',
											description = 'Source width.'
										},
										{
											type = 'number',
											name = 'sh',
											description = 'Source height.'
										}
									}
								}
							}
						},
						{
							name = 'setPixel',
							description = 'Sets the color of a pixel.\n\nValid x and y values start at 0 and go up to image width and height minus 1.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The position of the pixel on the x-axis.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The position of the pixel on the y-axis.'
										},
										{
											type = 'number',
											name = 'r',
											description = 'The red component (0-255).'
										},
										{
											type = 'number',
											name = 'g',
											description = 'The green component (0-255).'
										},
										{
											type = 'number',
											name = 'b',
											description = 'The blue component (0-255).'
										},
										{
											type = 'number',
											name = 'a',
											description = 'The alpha component (0-255).'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Data',
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'newEncodedImageData',
					description = 'Encodes ImageData.',
					functions = {
						{
							arguments = {
								{
									type = 'ImageData',
									name = 'imageData',
									description = 'The raw ImageData to encode.'
								},
								{
									type = 'ImageFormat',
									name = 'format',
									description = 'The format to encode the image in.'
								}
							},
							returns = {
								{
									type = 'Data',
									name = 'data',
									description = 'The encoded image data.'
								}
							}
						}
					}
				},
				{
					name = 'newImageData',
					description = 'Create a new ImageData object.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'width',
									description = 'The width of the ImageData.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The height of the ImageData.'
								}
							},
							returns = {
								{
									type = 'ImageData',
									name = 'imageData',
									description = 'The new ImageData object.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The filename of the image file.'
								}
							},
							returns = {
								{
									type = 'ImageData',
									name = 'imageData',
									description = 'The new ImageData object.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'Data',
									name = 'data',
									description = 'The encoded data to decode into image data.'
								}
							},
							returns = {
								{
									type = 'ImageData',
									name = 'imageData',
									description = 'The new ImageData object.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'ImageData',
					description = 'Encoded image formats.',
					constants = {
						{
							name = 'bmp',
							description = 'BMP image format.'
						},
						{
							name = 'tga',
							description = 'Targa image format.'
						},
						{
							name = 'png',
							description = 'PNG image format.'
						},
						{
							name = 'jpg',
							description = 'JPG image format.'
						},
						{
							name = 'gif',
							description = 'GIF image format.'
						}
					}
				}
			}
		},
		{
			name = 'joystick',
			description = 'Provides an interface to the user\'s joystick.',
			functions = {
				{
					name = 'close',
					description = 'Closes a joystick, i.e. stop using it for generating events and in query functions.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be closed.'
								}
							}
						}
					}
				},
				{
					name = 'getAxes',
					description = 'Returns the position of each axis.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'axisDir1',
									description = 'Direction of axis1.'
								},
								{
									type = 'number',
									name = 'axisDir2',
									description = 'Direction of axis2.'
								},
								{
									type = 'number',
									name = 'axisDirN',
									description = 'Direction of axisN.'
								}
							}
						}
					}
				},
				{
					name = 'getAxis',
					description = 'Returns the direction of the axis.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								},
								{
									type = 'number',
									name = 'axis',
									description = 'The axis to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'direction',
									description = 'Current value of the axis.'
								}
							}
						}
					}
				},
				{
					name = 'getBall',
					description = 'Returns the change in Ball position.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								},
								{
									type = 'number',
									name = 'ball',
									description = 'The ball to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'dx',
									description = 'Change in x of the ball position.'
								},
								{
									type = 'number',
									name = 'dy',
									description = 'Change in y of the ball position.'
								}
							}
						}
					}
				},
				{
					name = 'getHat',
					description = 'Returns the direction of a hat.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								},
								{
									type = 'number',
									name = 'hat',
									description = 'The hat to be checked.'
								}
							},
							returns = {
								{
									type = 'JoystickConstant',
									name = 'direction',
									description = 'The direction the hat is pushed.'
								}
							}
						}
					}
				},
				{
					name = 'getName',
					description = 'Returns the name of a joystick.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'string',
									name = 'name',
									description = 'The name of the joystick.'
								}
							}
						}
					}
				},
				{
					name = 'getNumBalls',
					description = 'Returns the number of balls on the joystick.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'balls',
									description = 'The number of balls available.'
								}
							}
						}
					}
				},
				{
					name = 'getNumButtons',
					description = 'Returns the number of buttons on the joystick.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'buttons',
									description = 'The number of buttons available.'
								}
							}
						}
					}
				},
				{
					name = 'getNumHats',
					description = 'Returns the number of hats on the joystick.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'hats',
									description = 'How many hats the joystick has.'
								}
							}
						}
					}
				},
				{
					name = 'getNumJoysticks',
					description = 'Returns how many joysticks are available.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'joysticks',
									description = 'The number of joysticks available.'
								}
							}
						}
					}
				},
				{
					name = 'isDown',
					description = 'Checks if a button on a joystick is pressed.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								},
								{
									type = 'number',
									name = 'button',
									description = 'The button to be checked.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'down',
									description = 'True if the button is down, false if it is not.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								},
								{
									type = 'number',
									name = '...',
									description = 'A button to check.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'anyDown',
									description = 'True if any supplied button is down, false if not.'
								}
							}
						}
					}
				},
				{
					name = 'isOpen',
					description = 'Checks if the joystick is open.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'open',
									description = 'True if the joystick is open, false if it is closed.'
								}
							}
						}
					}
				},
				{
					name = 'open',
					description = 'Opens up a joystick to be used, i.e. makes it ready to use. By default joysticks that are available at the start of your game will be opened.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be opened.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'open',
									description = 'True if the joystick has been successfully opened or false on failure.'
								}
							}
						}
					}
				},
				{
					name = 'getNumAxes',
					description = 'Returns the number of axes on the joystick.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'joystick',
									description = 'The joystick to be checked.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'axes',
									description = 'The number of axes available.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'JoystickConstant',
					description = 'Joystick hat positions.',
					constants = {
						{
							name = 'c',
							description = 'Centered'
						},
						{
							name = 'd',
							description = 'Down'
						},
						{
							name = 'l',
							description = 'Left'
						},
						{
							name = 'ld',
							description = 'Left+Down'
						},
						{
							name = 'lu',
							description = 'Left+Up'
						},
						{
							name = 'r',
							description = 'Right'
						},
						{
							name = 'rd',
							description = 'Right+Down'
						},
						{
							name = 'ru',
							description = 'Right+Up'
						},
						{
							name = 'u',
							description = 'Up'
						}
					}
				}
			}
		},
		{
			name = 'keyboard',
			description = 'Provides an interface to the user\'s keyboard.',
			functions = {
				{
					name = 'getKeyRepeat',
					description = 'Returns the delay and interval of key repeating.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'delay',
									description = 'The amount of time before repeating the key (in milliseconds)'
								},
								{
									type = 'number',
									name = 'interval',
									description = 'The amount of time between repeats (in milliseconds)'
								}
							}
						}
					}
				},
				{
					name = 'isDown',
					description = 'Checks whether a certain key is down. Not to be confused with love.keypressed or love.keyreleased.',
					functions = {
						{
							arguments = {
								{
									type = 'KeyConstant',
									name = 'key',
									description = 'The key to check.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'down',
									description = 'True if the key is down, false if not.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'KeyConstant',
									name = '...',
									description = 'A key to check.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'anyDown',
									description = 'True if any supplied key is down, false if not.'
								}
							}
						}
					}
				},
				{
					name = 'setKeyRepeat',
					description = 'Enables key repeating and sets the delay and interval.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'delay',
									description = 'The amount of time before repeating the key (in milliseconds). 0 disables key repeat.'
								},
								{
									type = 'number',
									name = 'interval',
									description = 'The amount of time between repeats (in milliseconds)'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'KeyConstant',
					description = 'All the keys you can press. Note that some keys may not be available on your keyboard or system.',
					constants = {
						{
							name = 'a',
							description = 'The A key'
						},
						{
							name = 'b',
							description = 'The B key'
						},
						{
							name = 'c',
							description = 'The C key'
						},
						{
							name = 'd',
							description = 'The D key'
						},
						{
							name = 'e',
							description = 'The E key'
						},
						{
							name = 'f',
							description = 'The F key'
						},
						{
							name = 'g',
							description = 'The G key'
						},
						{
							name = 'h',
							description = 'The H key'
						},
						{
							name = 'i',
							description = 'The I key'
						},
						{
							name = 'j',
							description = 'The J key'
						},
						{
							name = 'k',
							description = 'The K key'
						},
						{
							name = 'l',
							description = 'The L key'
						},
						{
							name = 'm',
							description = 'The M key'
						},
						{
							name = 'n',
							description = 'The N key'
						},
						{
							name = 'o',
							description = 'The O key'
						},
						{
							name = 'p',
							description = 'The P key'
						},
						{
							name = 'q',
							description = 'The Q key'
						},
						{
							name = 'r',
							description = 'The R key'
						},
						{
							name = 's',
							description = 'The S key'
						},
						{
							name = 't',
							description = 'The T key'
						},
						{
							name = 'u',
							description = 'The U key'
						},
						{
							name = 'v',
							description = 'The V key'
						},
						{
							name = 'w',
							description = 'The W key'
						},
						{
							name = 'x',
							description = 'The X key'
						},
						{
							name = 'y',
							description = 'The Y key'
						},
						{
							name = 'z',
							description = 'The Z key'
						},
						{
							name = '0',
							description = 'The zero key'
						},
						{
							name = '1',
							description = 'The one key'
						},
						{
							name = '2',
							description = 'The two key'
						},
						{
							name = '3',
							description = 'The three key'
						},
						{
							name = '4',
							description = 'The four key'
						},
						{
							name = '5',
							description = 'The five key'
						},
						{
							name = '6',
							description = 'The six key'
						},
						{
							name = '7',
							description = 'The seven key'
						},
						{
							name = '8',
							description = 'The eight key'
						},
						{
							name = '9',
							description = 'The nine key'
						},
						{
							name = '(space)',
							description = 'Space key',
							notes = 'Replace (space) with the actual space character'
						},
						{
							name = '!',
							description = 'Exclamation mark key'
						},
						{
							name = '"',
							description = 'Double quote key'
						},
						{
							name = '#',
							description = 'Hash key'
						},
						{
							name = '$',
							description = 'Dollar key'
						},
						{
							name = '&',
							description = 'Ampersand key'
						},
						{
							name = '\'',
							description = 'Single quote key'
						},
						{
							name = '(',
							description = 'Left parenthesis key'
						},
						{
							name = ')',
							description = 'Right parenthesis key'
						},
						{
							name = '*',
							description = 'Asterisk key'
						},
						{
							name = '+',
							description = 'Plus key'
						},
						{
							name = ',',
							description = 'Comma key'
						},
						{
							name = '-',
							description = 'Hyphen-minus key'
						},
						{
							name = '.',
							description = 'Full stop key'
						},
						{
							name = '/',
							description = 'Slash key'
						},
						{
							name = ':',
							description = 'Colon key'
						},
						{
							name = ';',
							description = 'Semicolon key'
						},
						{
							name = '<',
							description = 'Less-than key'
						},
						{
							name = '=',
							description = 'Equal key'
						},
						{
							name = '>',
							description = 'Greater-than key'
						},
						{
							name = '?',
							description = 'Question mark key'
						},
						{
							name = '@',
							description = 'At sign key'
						},
						{
							name = '?',
							description = 'Question mark key'
						},
						{
							name = '[',
							description = 'Left square bracket key'
						},
						{
							name = '\\',
							description = 'Backslash key'
						},
						{
							name = ']',
							description = 'Right square bracket key'
						},
						{
							name = '^',
							description = 'Caret key'
						},
						{
							name = '_',
							description = 'Underscore key'
						},
						{
							name = '`',
							description = 'Grave accent key',
							notes = 'Also known as the "Back tick" key'
						},
						{
							name = 'kp0',
							description = 'The numpad zero key'
						},
						{
							name = 'kp1',
							description = 'The numpad one key'
						},
						{
							name = 'kp2',
							description = 'The numpad two key'
						},
						{
							name = 'kp3',
							description = 'The numpad three key'
						},
						{
							name = 'kp4',
							description = 'The numpad four key'
						},
						{
							name = 'kp5',
							description = 'The numpad five key'
						},
						{
							name = 'kp6',
							description = 'The numpad six key'
						},
						{
							name = 'kp7',
							description = 'The numpad seven key'
						},
						{
							name = 'kp8',
							description = 'The numpad eight key'
						},
						{
							name = 'kp9',
							description = 'The numpad nine key'
						},
						{
							name = 'kp.',
							description = 'The numpad decimal point key'
						},
						{
							name = 'kp/',
							description = 'The numpad division key'
						},
						{
							name = 'kp*',
							description = 'The numpad multiplication key'
						},
						{
							name = 'kp-',
							description = 'The numpad substraction key'
						},
						{
							name = 'kp+',
							description = 'The numpad addition key'
						},
						{
							name = 'kpenter',
							description = 'The numpad enter key'
						},
						{
							name = 'kp=',
							description = 'The numpad equals key'
						},
						{
							name = 'up',
							description = 'Up cursor key'
						},
						{
							name = 'down',
							description = 'Down cursor key'
						},
						{
							name = 'right',
							description = 'Right cursor key'
						},
						{
							name = 'left',
							description = 'Left cursor key'
						},
						{
							name = 'home',
							description = 'Home key'
						},
						{
							name = 'end',
							description = 'End key'
						},
						{
							name = 'pageup',
							description = 'Page up key'
						},
						{
							name = 'pagedown',
							description = 'Page down key'
						},
						{
							name = 'insert',
							description = 'Insert key'
						},
						{
							name = 'backspace',
							description = 'Backspace key'
						},
						{
							name = 'tab',
							description = 'Tab key'
						},
						{
							name = 'clear',
							description = 'Clear key'
						},
						{
							name = 'return',
							description = 'Return key',
							notes = 'Also known as the Enter key'
						},
						{
							name = 'delete',
							description = 'Delete key'
						},
						{
							name = 'f1',
							description = 'The 1st function key'
						},
						{
							name = 'f2',
							description = 'The 2nd function key'
						},
						{
							name = 'f3',
							description = 'The 3rd function key'
						},
						{
							name = 'f4',
							description = 'The 4th function key'
						},
						{
							name = 'f5',
							description = 'The 5th function key'
						},
						{
							name = 'f6',
							description = 'The 6th function key'
						},
						{
							name = 'f7',
							description = 'The 7th function key'
						},
						{
							name = 'f8',
							description = 'The 8th function key'
						},
						{
							name = 'f9',
							description = 'The 9th function key'
						},
						{
							name = 'f10',
							description = 'The 10th function key'
						},
						{
							name = 'f11',
							description = 'The 11th function key'
						},
						{
							name = 'f12',
							description = 'The 12th function key'
						},
						{
							name = 'f13',
							description = 'The 13th function key'
						},
						{
							name = 'f14',
							description = 'The 14th function key'
						},
						{
							name = 'f15',
							description = 'The 15th function key'
						},
						{
							name = 'numlock',
							description = 'Num-lock key'
						},
						{
							name = 'capslock',
							description = 'Caps-lock key',
							notes = 'Caps-on is a key press. Caps-off is a key release.'
						},
						{
							name = 'scrollock',
							description = 'Scroll-lock key'
						},
						{
							name = 'rshift',
							description = 'Right shift key'
						},
						{
							name = 'lshift',
							description = 'Left shift key'
						},
						{
							name = 'rctrl',
							description = 'Right control key'
						},
						{
							name = 'lctrl',
							description = 'Left control key'
						},
						{
							name = 'ralt',
							description = 'Right alt key'
						},
						{
							name = 'lalt',
							description = 'Left alt key'
						},
						{
							name = 'rmeta',
							description = 'Right meta key'
						},
						{
							name = 'lmeta',
							description = 'Left meta key'
						},
						{
							name = 'lsuper',
							description = 'Left super key'
						},
						{
							name = 'rsuper',
							description = 'Right super key'
						},
						{
							name = 'mode',
							description = 'Mode key'
						},
						{
							name = 'compose',
							description = 'Compose key'
						},
						{
							name = 'pause',
							description = 'Pause key'
						},
						{
							name = 'escape',
							description = 'Escape key'
						},
						{
							name = 'help',
							description = 'Help key'
						},
						{
							name = 'print',
							description = 'Print key'
						},
						{
							name = 'sysreq',
							description = 'System request key'
						},
						{
							name = 'break',
							description = 'Break key'
						},
						{
							name = 'menu',
							description = 'Menu key'
						},
						{
							name = 'power',
							description = 'Power key'
						},
						{
							name = 'euro',
							description = 'Euro () key'
						},
						{
							name = 'undo',
							description = 'Undo key'
						}
					}
				}
			}
		},
		{
			name = 'mouse',
			description = 'Provides an interface to the user\'s mouse.',
			functions = {
				{
					name = 'getPosition',
					description = 'Returns the current position of the mouse.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'x',
									description = 'The position of the mouse along the x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The position of the mouse along the y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'getX',
					description = 'Returns the current x-position of the mouse.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'x',
									description = 'The position of the mouse along the x-axis.'
								}
							}
						}
					}
				},
				{
					name = 'getY',
					description = 'Returns the current y-position of the mouse.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'y',
									description = 'The position of the mouse along the y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'isDown',
					description = 'Checks whether a certain mouse button is down.',
					functions = {
						{
							arguments = {
								{
									type = 'MouseConstant',
									name = 'button',
									description = 'The button to check.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'down',
									description = 'True if the specified button is down.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'MouseConstant',
									name = '...',
									description = 'A button to check.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'anyDown',
									description = 'True if any specified button is down, false otherwise.'
								}
							}
						}
					}
				},
				{
					name = 'isGrabbed',
					description = 'Checks if the mouse is grabbed.',
					functions = {
						{
							returns = {
								{
									type = 'boolean',
									name = 'grabbed',
									description = 'True if the cursor is grabbed, false if it is not.'
								}
							}
						}
					}
				},
				{
					name = 'isVisible',
					description = 'Checks if the cursor is visible.',
					functions = {
						{
							returns = {
								{
									type = 'boolean',
									name = 'visible',
									description = 'True if the cursor to visible, false if the cursor is hidden.'
								}
							}
						}
					}
				},
				{
					name = 'setGrab',
					description = 'Grabs the mouse and confines it to the window.',
					functions = {
						{
							arguments = {
								{
									type = 'boolean',
									name = 'grab',
									description = 'True to confine the mouse, false to let it leave the window.'
								}
							}
						}
					}
				},
				{
					name = 'setPosition',
					description = 'Sets the current position of the mouse.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'x',
									description = 'The new position of the mouse along the x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The new position of the mouse along the y-axis.'
								}
							}
						}
					}
				},
				{
					name = 'setVisible',
					description = 'Sets the current visibility of the cursor.',
					functions = {
						{
							arguments = {
								{
									type = 'boolean',
									name = 'visible',
									description = 'True to set the cursor to visible, false to hide the cursor.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'MouseConstant',
					description = 'Mouse buttons.',
					constants = {
						{
							name = 'l',
							description = 'Left mouse button.'
						},
						{
							name = 'm',
							description = 'Middle mouse button.'
						},
						{
							name = 'r',
							description = 'Right mouse button.'
						},
						{
							name = 'wd',
							description = 'Mouse wheel down.'
						},
						{
							name = 'wu',
							description = 'Mouse wheel up.'
						},
						{
							name = 'x1',
							description = 'Mouse X1 (also known as button 4).'
						},
						{
							name = 'x2',
							description = 'Mouse X2 (also known as button 5).'
						}
					}
				}
			}
		},
		{
			name = 'physics',
			description = 'Can simulate 2D rigid body physics in a realistic manner. This module is based on Box2D, and this API corresponds to the Box2D API as closely as possible.',
			types = {
				{
					name = 'Body',
					description = 'Bodies are objects with velocity and position.',
					constructors = {
						'newBody'
					},
					functions = {
						{
							name = 'applyAngularImpulse',
							description = 'Applies an angular impulse to a body. This makes a single, instantaneous addition to the body momentum.\n\nA body with with a larger mass will react less. The reaction does not depend on the timestep, and is equivalent to applying a force continuously for 1 second. Impulses are best used to give a single push to a body. For a continuous push to a body it is better to use Body:applyForce.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'impulse',
											description = 'The impulse in kilogram-square meter per second.'
										}
									}
								}
							}
						},
						{
							name = 'applyForce',
							description = 'Apply force to a Body.\n\nA force pushes a body in a direction. A body with with a larger mass will react less. The reaction also depends on how long a force is applied: since the force acts continuously over the entire timestep, a short timestep will only push the body for a short time. Thus forces are best used for many timesteps to give a continuous push to a body (like gravity). For a single push that is independent of timestep, it is better to use Body:applyImpulse.\n\nIf the position to apply the force is not given, it will act on the center of mass of the body. The part of the force not directed towards the center of mass will cause the body to spin (and depends on the rotational inertia).\n\nNote that the force components and position must be given in world coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'fx',
											description = 'The x component of force to apply to the center of mass.'
										},
										{
											type = 'number',
											name = 'fy',
											description = 'The y component of force to apply to the center of mass.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'number',
											name = 'fx',
											description = 'The x component of force to apply.'
										},
										{
											type = 'number',
											name = 'fy',
											description = 'The y component of force to apply.'
										},
										{
											type = 'number',
											name = 'x',
											description = 'The x position to apply the force.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position to apply the force.'
										}
									}
								}
							}
						},
						{
							name = 'applyLinearImpulse',
							description = 'Applies an impulse to a body. This makes a single, instantaneous addition to the body momentum.\n\nAn impulse pushes a body in a direction. A body with with a larger mass will react less. The reaction does not depend on the timestep, and is equivalent to applying a force continuously for 1 second. Impulses are best used to give a single push to a body. For a continuous push to a body it is better to use Body:applyForce.\n\nIf the position to apply the impulse is not given, it will act on the center of mass of the body. The part of the impulse not directed towards the center of mass will cause the body to spin (and depends on the rotational inertia).\n\nNote that the impulse components and position must be given in world coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'ix',
											description = 'The x component of the impulse applied to the center of mass.'
										},
										{
											type = 'number',
											name = 'iy',
											description = 'The y component of the impulse applied to the center of mass.'
										}
									}
								},
								{
									arguments = {
										{
											type = 'number',
											name = 'ix',
											description = 'The x component of the impulse.'
										},
										{
											type = 'number',
											name = 'iy',
											description = 'The y component of the impulse.'
										},
										{
											type = 'number',
											name = 'x',
											description = 'The x position to apply the impulse.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position to apply the impulse.'
										}
									}
								}
							}
						},
						{
							name = 'applyTorque',
							description = 'Apply torque to a body.\n\nTorque is like a force that will change the angular velocity (spin) of a body. The effect will depend on the rotational inertia a body has.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'torque',
											description = 'The torque to apply.'
										}
									}
								}
							}
						},
						{
							name = 'destroy',
							description = 'Explicitly destroys the Body. When you don\'t have time to wait for garbage collection, this function may be used to free the object immediately, but note that an error will occur if you attempt to use the object after calling this function.',
							functions = {
								{}
							}
						},
						{
							name = 'getAllowSleeping',
							description = 'Return whether a body is allowed to sleep.\n\nA sleeping body is much more efficient to simulate than when awake.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'True when the body is allowed to sleep.'
										}
									}
								}
							}
						},
						{
							name = 'getAngle',
							description = 'Get the angle of the body.\n\nThe angle is measured in radians. If you need to transform it to degrees, use math.deg.\n\nA value of 0 radians will mean "looking to the right". Although radians increase counter-clockwise, the y axis points down so it becomes clockwise from our point of view.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'angle',
											description = 'The angle in radians.'
										}
									}
								}
							}
						},
						{
							name = 'getAngularDamping',
							description = 'Gets the Angular damping of the Body\n\nThe angular damping is the rate of decrease of the angular velocity over time: A spinning body with no damping and no external forces will continue spinning indefinitely. A spinning body with damping will gradually stop spinning.\n\nDamping is not the same as friction - they can be modelled together. However, only damping is provided by Box2D (and LVE).\n\nDamping parameters should be between 0 and infinity, with 0 meaning no damping, and infinity meaning full damping. Normally you will use a damping value between 0 and 0.1.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'damping',
											description = 'The value of the angular damping.'
										}
									}
								}
							}
						},
						{
							name = 'getAngularVelocity',
							description = 'Get the angular velocity of the Body.\n\nThe angular velocity is the rate of change of angle over time.\n\nIt is changed in World:update by applying torques, off centre forces/impulses, and angular damping. It can be set directly with Body:setAngularVelocity.\n\nIf you need the rate of change of position over time, use Body:getLinearVelocity.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'w',
											description = 'The angular velocity in radians/second.'
										}
									}
								}
							}
						},
						{
							name = 'getFixtureList',
							description = 'Returns a table with all fixtures.',
							functions = {
								{
									returns = {
										{
											type = 'table',
											name = 'fixtures',
											description = 'A sequence with all fixtures.'
										}
									}
								}
							}
						},
						{
							name = 'getInertia',
							description = 'Gets the rotational inertia of the body.\n\nThe rotational inertia is how hard is it to make the body spin. It is set with the 4th argument to Body:setMass, or automatically with Body:setMassFromShapes.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'inertia',
											description = 'The rotational inertial of the body.'
										}
									}
								}
							}
						},
						{
							name = 'getLinearDamping',
							description = 'Gets the linear damping of the Body.\n\nThe linear damping is the rate of decrease of the linear velocity over time. A moving body with no damping and no external forces will continue moving indefinitely, as is the case in space. A moving body with damping will gradually stop moving.\n\nDamping is not the same as friction - they can be modelled together. However, only damping is provided by Box2D (and LVE).',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'damping',
											description = 'The value of the linear damping.'
										}
									}
								}
							}
						},
						{
							name = 'getLinearVelocity',
							description = 'Gets the linear velocity of the Body from its center of mass.\n\nThe linear velocity is the rate of change of position over time.\n\nIf you need the rate of change of angle over time, use Body:getAngularVelocity. If you need to get the linear velocity of a point different from the center of mass:\n\nBody:getLinearVelocityFromLocalPoint allows you to specify the point in local coordinates.\nBody:getLinearVelocityFromWorldPoint allows you to specify the point in world coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the velocity vector.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y-component of the velocity vector.'
										}
									}
								}
							}
						},
						{
							name = 'getLinearVelocityFromLocalPoint',
							description = 'Get the linear velocity of a point on the body.\n\nThe linear velocity for a point on the body is the velocity of the body center of mass plus the velocity at that point from the body spinning.\n\nThe point on the body must given in local coordinates. Use Body:getLinearVelocityFromWorldPoint to specify this with world coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position to measure velocity.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position to measure velocity.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'vx',
											description = 'The x component of velocity at point (x,y).'
										},
										{
											type = 'number',
											name = 'vy',
											description = 'The y component of velocity at point (x,y).'
										}
									}
								}
							}
						},
						{
							name = 'getLinearVelocityFromWorldPoint',
							description = 'Get the linear velocity of a point on the body.\n\nThe linear velocity for a point on the body is the velocity of the body center of mass plus the velocity at that point from the body spinning.\n\nThe point on the body must given in world coordinates. Use Body:getLinearVelocityFromLocalPoint to specify this with local coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position to measure velocity.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position to measure velocity.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'vx',
											description = 'The x component of velocity at point (x,y).'
										},
										{
											type = 'number',
											name = 'vy',
											description = 'The y component of velocity at point (x,y).'
										}
									}
								}
							}
						},
						{
							name = 'getLocalCenter',
							description = 'Get the center of mass position in local coordinates.\n\nUse Body:getWorldCenter to get the center of mass in world coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x coordinate of the center of mass.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y coordinate of the center of mass.'
										}
									}
								}
							}
						},
						{
							name = 'getLocalPoint',
							description = 'Transform a point from world coordinates to local coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'world_x',
											description = 'The x position in world coordinates.'
										},
										{
											type = 'number',
											name = 'world_y',
											description = 'The y position in world coordinates.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'local_x',
											description = 'The x position in local coordinates.'
										},
										{
											type = 'number',
											name = 'local_y',
											description = 'The y position in local coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'getLocalVector',
							description = 'Transform a vector from world coordinates to local coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'world_x',
											description = 'The vector x component in world coordinates.'
										},
										{
											type = 'number',
											name = 'world_y',
											description = 'The vector y component in world coordinates.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'local_x',
											description = 'The vector x component in local coordinates.'
										},
										{
											type = 'number',
											name = 'local_y',
											description = 'The vector y component in local coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'getMass',
							description = 'Get the mass of the body.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'mass',
											description = 'The mass of the body (in kilograms).'
										}
									}
								}
							}
						},
						{
							name = 'getMassData',
							description = 'Returns the mass, its center, and the rotational inertia.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position of the center of mass.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position of the center of mass.'
										},
										{
											type = 'number',
											name = 'mass',
											description = 'The mass of the body.'
										},
										{
											type = 'number',
											name = 'inertia',
											description = 'The rotational inertia.'
										}
									}
								}
							}
						},
						{
							name = 'getPosition',
							description = 'Get the position of the body.\n\nNote that this may not be the center of mass of the body.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position.'
										}
									}
								}
							}
						},
						{
							name = 'getType',
							description = 'Returns the type of the body.',
							functions = {
								{
									returns = {
										{
											type = 'BodyType',
											name = 'type',
											description = 'The body type.'
										}
									}
								}
							}
						},
						{
							name = 'getWorldCenter',
							description = 'Get the center of mass position in world coordinates.\n\nUse Body:getLocalCenter to get the center of mass in local coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x coordinate of the center of mass.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y coordinate of the center of mass.'
										}
									}
								}
							}
						},
						{
							name = 'getWorldPoint',
							description = 'Transform a point from local coordinates to world coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'local_x',
											description = 'The x position in local coordinates.'
										},
										{
											type = 'number',
											name = 'local_y',
											description = 'The y position in local coordinates.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'world_x',
											description = 'The x position in world coordinates.'
										},
										{
											type = 'number',
											name = 'world_y',
											description = 'The y position in world coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'getWorldPoints',
							description = 'Transforms multiple points from local coordinates to world coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x position of the first point.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y position of the first point.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x position of the second point.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y position of the second point.'
										},
										{
											type = 'number',
											name = '...',
											description = 'More x and y points.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'x1',
											description = 'The transformed x position of the first point.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The transformed y position of the first point.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The transformed x position of the second point.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The transformed y position of the second point.'
										},
										{
											type = 'number',
											name = '...',
											description = 'The transformed x and y positions of additional points.'
										}
									}
								}
							}
						},
						{
							name = 'getWorldVector',
							description = 'Transform a vector from local coordinates to world coordinates.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'local_x',
											description = 'The vector x component in local coordinates.'
										},
										{
											type = 'number',
											name = 'local_y',
											description = 'The vector y component in local coordinates.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'world_x',
											description = 'The vector x component in world coordinates.'
										},
										{
											type = 'number',
											name = 'world_y',
											description = 'The vector y component in world coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'getX',
							description = 'Get the x position of the body in world coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position in world coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'getY',
							description = 'Get the y position of the body in world coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'y',
											description = 'The y position in world coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'isActive',
							description = 'Returns whether the body is actively used in the simulation.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'True if the body is active or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'isAwake',
							description = 'Returns the sleep status of the body.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'True if the body is awake or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'isBullet',
							description = 'Get the bullet status of a body.\n\nThere are two methods to check for body collisions:\n\nat their location when the world is updated (default)\nusing continuous collision detection (CCD)\n\nThe default method is efficient, but a body moving very quickly may sometimes jump over another body without producing a collision. A body that is set as a bullet will use CCD. This is less efficient, but is guaranteed not to jump when moving quickly.\n\nNote that static bodies (with zero mass) always use CCD, so your walls will not let a fast moving body pass through even if it is not a bullet.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'The bullet status of the body.'
										}
									}
								}
							}
						},
						{
							name = 'isDynamic',
							description = 'Get the dynamic status of the body.\n\nA static body has no mass and a constant position. It will not react to collisions. Often used for walls.\n\nA dynamic body has mass and can move. It will react to collisions when the world is updated.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'The dynamic status of the body.'
										}
									}
								}
							}
						},
						{
							name = 'isFixedRotation',
							description = 'Returns whether the body rotation is locked.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'fixed',
											description = 'True if the body\'s rotation is locked or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'isFrozen',
							description = 'Get the frozen status of the body.\n\nA body becomes frozen when it goes outside the world boundary. A frozen body is no longer changed by World:update.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'The frozen status of the body.'
										}
									}
								}
							}
						},
						{
							name = 'isSleeping',
							description = 'Get the sleeping status of a body.\n\nA sleeping body is much more efficient to simulate than when awake.\n\nIf sleeping is allowed, a body that has come to rest will sleep.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'The sleeping status of the body.'
										}
									}
								}
							}
						},
						{
							name = 'isSleepingAllowed',
							description = 'Returns the sleeping behaviour of the body.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'True if the body is allowed to sleep or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'isStatic',
							description = 'Get the static status of the body.\n\nA static body has no mass and a constant position. It will not react to collisions. Often used for walls.\n\nA dynamic body has mass and can move. It will react to collisions when the world is updated.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'status',
											description = 'The static status of the body.'
										}
									}
								}
							}
						},
						{
							name = 'putToSleep',
							description = 'Put the body to sleep.\n\nA sleeping body is much more efficient to simulate than when awake.\n\nThe body will wake up if another body collides with it, if a joint or contact attached to it is destroyed, or if Body:wakeUp is called.',
							functions = {
								{}
							}
						},
						{
							name = 'resetMassData',
							description = 'Resets the mass of the body by recalculating it from the mass properties of the fixtures.',
							functions = {
								{}
							}
						},
						{
							name = 'setAllowSleeping',
							description = 'Set the sleep behaviour of a body.\n\nA sleeping body is much more efficient to simulate than when awake.\n\nIf sleeping is allowed, a body that has come to rest will sleep.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'permission',
											description = 'Permission for the body to sleep.'
										}
									}
								}
							}
						},
						{
							name = 'setAngle',
							description = 'Set the angle of the body.\n\nThe angle is measured in radians. If you need to transform it from degrees, use math.rad.\n\nA value of 0 radians will mean "looking to the right". .Although radians increase counter-clockwise, the y axis points down so it becomes clockwise from our point of view.\n\nIt is possible to cause a collision with another body by changing its angle.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'angle',
											description = 'The angle in radians.'
										}
									}
								}
							}
						},
						{
							name = 'setAngularDamping',
							description = 'Sets the angular damping of a Body.\n\nSee Body:getAngularDamping for a definition of angular damping.\n\nAngular damping can take any value from 0 to infinity. It is recommended to stay between 0 and 0.1, though. Other values will look unrealistic.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'damping',
											description = 'The new angular damping.'
										}
									}
								}
							}
						},
						{
							name = 'setAngularVelocity',
							description = 'Sets the angular velocity of a Body.\n\nThe angular velocity is the rate of change of angle over time.\n\nThis function will not accumulate anything; any impulses previously applied since the last call to World:update will be lost.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'w',
											description = 'The new angular velocity, in radians per second'
										}
									}
								}
							}
						},
						{
							name = 'setAwake',
							description = 'Wakes the body up or puts it to sleep.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'awake',
											description = 'The body sleep status.'
										}
									}
								}
							}
						},
						{
							name = 'setBullet',
							description = 'Set the bullet status of a body.\n\nThere are two methods to check for body collisions:\n\nat their location when the world is updated (default)\nusing continuous collision detection (CCD)\n\nThe default method is efficient, but a body moving very quickly may sometimes jump over another body without producing a collision. A body that is set as a bullet will use CCD. This is less efficient, but is guaranteed not to jump when moving quickly.\n\nNote that static bodies (with zero mass) always use CCD, so your walls will not let a fast moving body pass through even if it is not a bullet.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'status',
											description = 'The bullet status of the body.'
										}
									}
								}
							}
						},
						{
							name = 'setFixedRotation',
							description = 'Set whether a body has fixed rotation.\n\nBodies with fixed rotation don\'t vary the speed at which they rotate.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'isFixed',
											description = 'Whether the body should have fixed rotation.'
										}
									}
								}
							}
						},
						{
							name = 'setGravityScale',
							description = 'Sets a new gravity scale factor for the body.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'scale',
											description = 'The new gravity scale factor.'
										}
									}
								}
							}
						},
						{
							name = 'setInertia',
							description = 'Set the inertia of a body.\n\nThis value can also be set by the fourth argument of Body:setMass.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'inertia',
											description = 'The new moment of inertia, in kilograms per meter squared.'
										}
									}
								}
							}
						},
						{
							name = 'setLinearDamping',
							description = 'Sets the linear damping of a Body\n\nSee Body:getLinearDamping for a definition of linear damping.\n\nLinear damping can take any value from 0 to infinity. It is recommended to stay between 0 and 0.1, though. Other values will make the objects look "floaty".',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'ld',
											description = 'The new linear damping'
										}
									}
								}
							}
						},
						{
							name = 'setLinearVelocity',
							description = 'Sets a new linear velocity for the Body.\n\nThis function will not accumulate anything; any impulses previously applied since the last call to World:update will be lost.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the velocity vector.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y-component of the velocity vector.'
										}
									}
								}
							}
						},
						{
							name = 'setMass',
							description = 'Sets the mass in kilograms.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'mass',
											description = 'The mass, in kilograms.'
										}
									}
								}
							}
						},
						{
							name = 'setMassData',
							description = 'Sets the mass properties directly.\n\nIf you\'re not sure what all this stuff means, you can use Body:setMassFromShapes after adding shapes instead.\n\nThe first two parameters will be the local coordinates of the Body\'s center of mass.\n\nThe third parameter is the mass, in kilograms.\n\nThe last parameter is the rotational inertia.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the center of mass in local coordinates.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y-component of the center of mass in local coordinates.'
										},
										{
											type = 'number',
											name = 'mass',
											description = 'The mass, in kilograms.'
										},
										{
											type = 'number',
											name = 'inertia',
											description = 'The rotational inertia, in kilograms per squared meter.'
										}
									}
								}
							}
						},
						{
							name = 'setMassFromShapes',
							description = 'Sets mass properties from attatched shapes.\n\nIf you feel that finding the correct mass properties is tricky, then this function may be able to help you. After creating the needed shapes on the Body, a call to this function will set the mass properties based on those shapes. Remember to call this function after adding the shapes.\n\nSetting the mass properties this way always results in a realistic (or at least good-looking) simulation, so using it is highly recommended.',
							functions = {
								{}
							}
						},
						{
							name = 'setPosition',
							description = 'Set the position of the body.\n\nNote that this may not be the center of mass of the body.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position.'
										}
									}
								}
							}
						},
						{
							name = 'setSleepingAllowed',
							description = 'Sets the sleeping behaviour of the body.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'allowed',
											description = 'True if the body is allowed to sleep or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'setType',
							description = 'Sets a new body type.',
							functions = {
								{
									arguments = {
										{
											type = 'BodyType',
											name = 'type',
											description = 'The new type.'
										}
									}
								}
							}
						},
						{
							name = 'setX',
							description = 'Set the x position of the body.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position.'
										}
									}
								}
							}
						},
						{
							name = 'setY',
							description = 'Set the y position of the body.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'y',
											description = 'The y position.'
										}
									}
								}
							}
						},
						{
							name = 'wakeUp',
							description = 'Wake a sleeping body up.\n\nA sleeping body is much more efficient to simulate than when awake\n\nA sleeping body will also wake up if another body collides with it or if a joint or contact attached to it is destroyed.',
							functions = {
								{}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'CircleShape',
					description = 'Circle extends Shape and adds a radius and a local position.',
					constructors = {
						'newCircleShape'
					},
					functions = {
						{
							name = 'getLocalCenter',
							description = 'Get the center of the circle in local coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'lx',
											description = 'The x position of the circle in local coordinates.'
										},
										{
											type = 'number',
											name = 'ly',
											description = 'The y position of the circle in local coordinates.'
										}
									}
								}
							}
						},
						{
							name = 'getRadius',
							description = 'Gets the radius of the circle shape.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'radius',
											description = 'The radius of the circle.'
										}
									}
								}
							}
						},
						{
							name = 'getWorldCenter',
							description = 'Get the center of the circle in world coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'wx',
											description = 'The x position of the circle in world coordinates.'
										},
										{
											type = 'number',
											name = 'wy',
											description = 'The y position of the circle in world coordinates.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Shape',
						'Object'
					}
				},
				{
					name = 'Contact',
					description = 'Contacts are objects created to manage collisions in worlds.',
					functions = {
						{
							name = 'getFriction',
							description = 'Get the friction between two shapes that are in contact.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'friction',
											description = 'The friction of the contact.'
										}
									}
								}
							}
						},
						{
							name = 'getNormal',
							description = 'Get the normal vector between two shapes that are in contact.\n\nThis function returns the coordinates of a unit vector that points from the first shape to the second.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'nx',
											description = 'The x component of the normal vector.'
										},
										{
											type = 'number',
											name = 'ny',
											description = 'The y component of the normal vector.'
										}
									}
								}
							}
						},
						{
							name = 'getPosition',
							description = 'Get the location of the contact point between two shapes.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'cx',
											description = 'The x coordinate of the contact point.'
										},
										{
											type = 'number',
											name = 'cy',
											description = 'The y coordinate of the contact point.'
										}
									}
								}
							}
						},
						{
							name = 'getRestitution',
							description = 'Get the restitution between two shapes that are in contact.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'restitution',
											description = 'The restitution between the two shapes.'
										}
									}
								}
							}
						},
						{
							name = 'getSeparation',
							description = 'Get the separation between two shapes that are in contact.\n\nThe return value of this function is always zero or negative, with a negative value indicating overlap between the two shapes.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'distance',
											description = 'The separation between the two shapes.'
										}
									}
								}
							}
						},
						{
							name = 'getVelocity',
							description = 'Get the linear impact velocity of a contact.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'vx',
											description = 'The x component of the velocity vector.'
										},
										{
											type = 'number',
											name = 'vy',
											description = 'The y component of the velocity vector.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'DistanceJoint',
					description = 'Keeps two bodies at the same distance.',
					constructors = {
						'newDistanceJoint'
					},
					functions = {
						{
							name = 'getDamping',
							description = 'Gets the damping ratio.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'ratio',
											description = 'The damping ratio.'
										}
									}
								}
							}
						},
						{
							name = 'getFrequency',
							description = 'Gets the response speed.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'Hz',
											description = 'The response speed.'
										}
									}
								}
							}
						},
						{
							name = 'getLength',
							description = 'Gets the equilibrium distance between the two Bodies.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'l',
											description = 'The length between the two Bodies.'
										}
									}
								}
							}
						},
						{
							name = 'setDampingRatio',
							description = 'Sets the damping ratio.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'ratio',
											description = 'The damping ratio.'
										}
									}
								}
							}
						},
						{
							name = 'setFrequency',
							description = 'Sets the response speed.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'Hz',
											description = 'The response speed.'
										}
									}
								}
							}
						},
						{
							name = 'setLength',
							description = 'Sets the equilibrium distance between the two Bodies.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'l',
											description = 'The length between the two Bodies.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'Fixture',
					description = 'Fixtures attach shapes to bodies.',
					constructors = {
						'newFixture'
					},
					functions = {
						{
							name = 'destroy',
							description = 'Destroys the fixture',
							functions = {
								{}
							}
						},
						{
							name = 'getBody',
							description = 'Returns the body to which the fixture is attached.',
							functions = {
								{
									returns = {
										{
											type = 'Body',
											name = 'body',
											description = 'The parent body.'
										}
									}
								}
							}
						},
						{
							name = 'getBoundingBox',
							description = 'Returns the points of the fixture bounding box. In case the fixture has multiple childern a 1-based index can be specified.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'index',
											default = '1',
											description = 'The fixture child to get the bounding box of.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'topLeftX',
											description = 'The x position of the top-left point.'
										},
										{
											type = 'number',
											name = 'topLeftY',
											description = 'The y position of the top-left point.'
										},
										{
											type = 'number',
											name = 'bottomRightX',
											description = 'The x position of the bottom-right point.'
										},
										{
											type = 'number',
											name = 'bottomRightY',
											description = 'The y position of the bottom-right point.'
										}
									}
								}
							}
						},
						{
							name = 'getCategory',
							description = 'Returns the categories the fixture belongs to.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'category1',
											description = 'The first category.'
										},
										{
											type = 'number',
											name = 'category2',
											description = 'The second category.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Additional categories.'
										}
									}
								}
							}
						},
						{
							name = 'getDensity',
							description = 'Returns the density of the fixture.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'density',
											description = 'The fixture density in kilograms per square meter.'
										}
									}
								}
							}
						},
						{
							name = 'getFilterData',
							description = 'Returns the filter data of the fixture. Categories and masks are encoded as the bits of a 16-bit integer.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'categories',
											description = 'The categories as an integer from 0 to 65535.'
										},
										{
											type = 'number',
											name = 'mask',
											description = 'The mask as an integer from 0 to 65535.'
										},
										{
											type = 'number',
											name = 'group',
											description = 'The group as an integer from -32768 to 32767.'
										}
									}
								}
							}
						},
						{
							name = 'getFriction',
							description = 'Returns the friction of the fixture.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'friction',
											description = 'The fixture friction.'
										}
									}
								}
							}
						},
						{
							name = 'getGroupIndex',
							description = 'Returns the group the fixture belongs to. Fixtures with the same group will always collide if the group is positive or never collide if it\'s negative. The group zero means no group.\n\nThe groups range from -32768 to 32767.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'group',
											description = 'The group of the fixture.'
										}
									}
								}
							}
						},
						{
							name = 'getMask',
							description = 'Returns the category mask of the fixture.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'mask1',
											description = 'The first category selected by the mask.'
										},
										{
											type = 'number',
											name = 'mask2',
											description = 'The second category selected by the mask.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Additional categories selected by the mask.'
										}
									}
								}
							}
						},
						{
							name = 'getMassData',
							description = 'Returns the mass, its center and the rotational inertia.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position of the center of mass.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position of the center of mass.'
										},
										{
											type = 'number',
											name = 'mass',
											description = 'The mass of the fixture.'
										},
										{
											type = 'number',
											name = 'inertia',
											description = 'The rotational inertia.'
										}
									}
								}
							}
						},
						{
							name = 'getRestitution',
							description = 'Returns the restitution of the fixture.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'restitution',
											description = 'The fixture restitution.'
										}
									}
								}
							}
						},
						{
							name = 'getShape',
							description = 'Returns the shape of the fixture. This shape is a reference to the actual data used in the simulation. It\'s possible to change its values between timesteps.\n\nDo not call any functions on this shape after the parent fixture has been destroyed. This shape will point to an invalid memory address and likely cause crashes if you interact further with it.',
							functions = {
								{
									returns = {
										{
											type = 'Shape',
											name = 'shape',
											description = 'The fixture\'s shape.'
										}
									}
								}
							}
						},
						{
							name = 'getUserData',
							description = 'Returns the Lua value associated with this fixture.\n\nUse this function in one thread only.',
							functions = {
								{
									returns = {
										{
											type = 'mixed',
											name = 'value',
											description = 'The Lua value associated with the fixture.'
										}
									}
								}
							}
						},
						{
							name = 'isSensor',
							description = 'Returns whether the fixture is a sensor.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'sensor',
											description = 'If the fixture is a sensor.'
										}
									}
								}
							}
						},
						{
							name = 'rayCast',
							description = 'Casts a ray against the shape of the fixture and returns the surface normal vector and the line position where the ray hit. If the ray missed the shape, nil will be returned.\n\nThe ray starts on the first point of the input line and goes towards the second point of the line. The fourth argument is the maximum distance the ray is going to travel as a scale factor of the input line length.\n\nThe world position of the impact can be calculated by multiplying the line vector with the third return value and adding it to the line starting point.\n\nThere is a bug in 0.8.0 where the normal vector returned by this function gets scaled by love.physics.getMeter.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x position of the ray starting point.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y position of the ray starting point.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x position of the ray end point.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y position of the ray end point.'
										},
										{
											type = 'number',
											name = 'maxFraction',
											description = 'The maximum distance the ray is going to travel as a number from 0 to 1.'
										},
										{
											type = 'number',
											name = 'childIndex',
											default = '1',
											description = 'The index of the child the ray gets cast against.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position where the ray intersects with the shape.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position where the ray intersects with the shape.'
										},
										{
											type = 'number',
											name = 'fraction',
											description = 'The position on the input vector where the intersection happened as a number from 0 to 1.'
										}
									}
								}
							}
						},
						{
							name = 'setCategory',
							description = 'Sets the categories the fixture belongs to. There can be up to 16 categories represented as a number from 1 to 16.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'category1',
											description = 'The first category.'
										},
										{
											type = 'number',
											name = 'category2',
											description = 'The second category.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Additional categories.'
										}
									}
								}
							}
						},
						{
							name = 'setDensity',
							description = 'Sets the density of the fixture. Call Body:resetMassData if this needs to take effect immediately.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'density',
											description = 'The fixture density in kilograms per square meter.'
										}
									}
								}
							}
						},
						{
							name = 'setFilterData',
							description = 'Sets the filter data of the fixture.\n\nGroups, categories, and mask can be used to define the collision behaviour of the fixture.\n\nIf two fixtures are in the same group they either always collide if the group is positive, or never collide if it\'s negative. Is the group zero or they do not match, then the contact filter checks if the fixtures select a category of the other fixture with their masks. The fixtures do not collide if that\'s not the case. If they do have each others categories selected, the return value of the custom contact filter will be used. They always collide if none was set.\n\nThere can be up to 16 categories. Categories and masks are encoded as the bits of a 16-bit integer.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'categories',
											description = 'The categories as an integer from 0 to 65535.'
										},
										{
											type = 'number',
											name = 'mask',
											description = 'The mask as an integer from 0 to 65535.'
										},
										{
											type = 'number',
											name = 'group',
											description = 'The group as an integer from -32768 to 32767.'
										}
									}
								}
							}
						},
						{
							name = 'setFriction',
							description = 'Sets the friction of the fixture.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'friction',
											description = 'The fixture friction.'
										}
									}
								}
							}
						},
						{
							name = 'setGroupIndex',
							description = 'Sets the group the fixture belongs to. Fixtures with the same group will always collide if the group is positive or never collide if it\'s negative. The group zero means no group.\n\nThe groups range from -32768 to 32767.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'group',
											description = 'The group as an integer from -32768 to 32767.'
										}
									}
								}
							}
						},
						{
							name = 'setMask',
							description = 'Sets the category mask of the fixture. There can be up to 16 categories represented as a number from 1 to 16.\n\nThis fixture will collide with the fixtures that are in the selected categories if the other fixture also has a category of this fixture selected.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'mask1',
											description = 'The first category.'
										},
										{
											type = 'number',
											name = 'mask2',
											description = 'The second category.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Additional categories.'
										}
									}
								}
							}
						},
						{
							name = 'setRestitution',
							description = 'Sets the restitution of the fixture.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'restitution',
											description = 'The fixture restitution.'
										}
									}
								}
							}
						},
						{
							name = 'setSensor',
							description = 'Sets whether the fixture should act as a sensor.\n\nSensor do not produce collisions responses, but the begin and end callbacks will still be called for this fixture.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'sensor',
											description = 'The sensor status.'
										}
									}
								}
							}
						},
						{
							name = 'setUserData',
							description = 'Associates a Lua value with the fixture.\n\nUse this function in one thread only.',
							functions = {
								{
									arguments = {
										{
											type = 'mixed',
											name = 'value',
											description = 'The Lua value associated with the fixture.'
										}
									}
								}
							}
						},
						{
							name = 'testPoint',
							description = 'Checks if a point is inside the shape of the fixture.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x position of the point.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y position of the point.'
										}
									},
									returns = {
										{
											type = 'boolean',
											name = 'isInside',
											description = 'True if the point is inside or false if it is outside.',
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'FrictionJoint',
					description = 'A FrictionJoint applies friction to a body.',
					constructors = {
						'newFrictionJoint'
					},
					functions = {
						{
							name = 'getMaxForce',
							description = 'Gets the maximum friction force in Newtons.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'force',
											description = 'Maximum force in Newtons.'
										}
									}
								}
							}
						},
						{
							name = 'getMaxTorque',
							description = 'Gets the maximum friction torque in Newton-meters.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'torque',
											description = 'Maximum torque in Newton-meters.'
										}
									}
								}
							}
						},
						{
							name = 'setMaxForce',
							description = 'Sets the maximum friction force in Newtons.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'maxForce',
											description = 'Max force in Newtons.'
										}
									}
								}
							}
						},
						{
							name = 'setMaxTorque',
							description = 'Sets the maximum friction torque in Newton-meters.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'torque',
											description = 'Maximum torque in Newton-meters.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'GearJoint',
					description = 'Keeps bodies together in such a way that they act like gears.',
					constructors = {
						'newGearJoint'
					},
					functions = {
						{
							name = 'getRatio',
							description = 'Get the ratio of a gear joint.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'ratio',
											description = 'The ratio of the joint.'
										}
									}
								}
							}
						},
						{
							name = 'setRatio',
							description = 'Set the ratio of a gear joint.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'ratio',
											description = 'The new ratio of the joint.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'Joint',
					description = 'Attach multiple bodies together to interact in unique ways.',
					functions = {
						{
							name = 'destroy',
							description = 'Explicitly destroys the Joint. When you don\'t have time to wait for garbage collection, this function may be used to free the object immediately, but note that an error will occur if you attempt to use the object after calling this function.',
							functions = {
								{}
							}
						},
						{
							name = 'getAnchors',
							description = 'Get the anchor points of the joint.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x-component of the anchor on Body 1.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y-component of the anchor on Body 1.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x-component of the anchor on Body 2.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y-component of the anchor on Body 2.'
										}
									}
								}
							}
						},
						{
							name = 'getCollideConnected',
							description = 'Gets whether the connected Bodies collide.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'c',
											description = 'True if they collide, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'getReactionForce',
							description = 'Gets the reaction force on Body 2 at the joint anchor.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the force.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y-component of the force.'
										}
									}
								}
							}
						},
						{
							name = 'getReactionTorque',
							description = 'Gets the reaction torque on Body 2.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'torque',
											description = 'The reaction torque on Body 2.'
										}
									}
								}
							}
						},
						{
							name = 'getType',
							description = 'Gets an string representing the type.',
							functions = {
								{
									returns = {
										{
											type = 'JointType',
											name = 'type',
											description = 'A string with the name of the Joint type.'
										}
									}
								}
							}
						},
						{
							name = 'setCollideConnected',
							description = 'Sets whether the connected Bodies should collide with eachother.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'collide',
											description = 'True for the Bodies to collide, false otherwise.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'MouseJoint',
					description = 'For controlling objects with the mouse.',
					constructors = {
						'newMouseJoint'
					},
					functions = {
						{
							name = 'getMaxForce',
							description = 'Gets the highest allowed force.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'f',
											description = 'The max allowed force.'
										}
									}
								}
							}
						},
						{
							name = 'getTarget',
							description = 'Gets the target point.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the target.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The x-component of the target.'
										}
									}
								}
							}
						},
						{
							name = 'setMaxForce',
							description = 'Sets the highest allowed force.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'f',
											description = 'The max allowed force.'
										}
									}
								}
							}
						},
						{
							name = 'setTarget',
							description = 'Sets the target point.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the target.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y-component of the target.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'PolygonShape',
					description = 'Polygon is a convex polygon with up to 8 sides.',
					constructors = {
						'newPolygonShape',
						'newRectangleShape'
					},
					functions = {
						{
							name = 'getPoints',
							description = 'Get the world coordinates of the polygon\'s vertices.\n\nThis function has a variable number of return values. It can be used in a nested fashion with love.graphics.polygon.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x-component of the first vertex.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y-component of the first vertex.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x-component of the second vertex.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y-component of the second vertex.'
										},
										{
											type = 'number',
											name = '...',
											description = 'Additional x and y values.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Shape',
						'Object'
					}
				},
				{
					name = 'PrismaticJoint',
					description = 'Restricts relative motion between Bodies to one shared axis.',
					constructors = {
						'newPrismaticJoint'
					},
					functions = {
						{
							name = 'getJointSpeed',
							description = 'Get the current joint angle speed.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 's',
											description = 'Joint angle speed in meters/second.'
										}
									}
								}
							}
						},
						{
							name = 'getJointTranslation',
							description = 'Get the current joint translation.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 't',
											description = 'Joint translation, usually in meters..'
										}
									}
								}
							}
						},
						{
							name = 'getLimits',
							description = 'Gets the joint limits.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, usually in meters.'
										},
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, usually in meters.'
										}
									}
								}
							}
						},
						{
							name = 'getLowerLimit',
							description = 'Gets the lower limit.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, usually in meters.'
										}
									}
								}
							}
						},
						{
							name = 'getMaxMotorForce',
							description = 'Gets the maximum motor force.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'f',
											description = 'The maximum motor force, usually in N.'
										}
									}
								}
							}
						},
						{
							name = 'getMotorForce',
							description = 'Get the current motor force.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'f',
											description = 'The current motor force, usually in N.'
										}
									}
								}
							}
						},
						{
							name = 'getMotorSpeed',
							description = 'Gets the motor speed.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 's',
											description = 'The motor speed, usually in meters per second.'
										}
									}
								}
							}
						},
						{
							name = 'getUpperLimit',
							description = 'Gets the upper limit.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, usually in meters.'
										}
									}
								}
							}
						},
						{
							name = 'isLimitsEnabled',
							description = 'Checks whether limits are enabled.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'enabled',
											description = 'True if enabled, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isMotorEnabled',
							description = 'Checks whether the motor is enabled.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'enabled',
											description = 'True if enabled, false if disabled.'
										}
									}
								}
							}
						},
						{
							name = 'setLimits',
							description = 'Sets the limits.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, usually in meters.'
										},
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, usually in meters.'
										}
									}
								}
							}
						},
						{
							name = 'setLimitsEnabled',
							description = 'Enables/disables the joint limit.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'enable',
											description = 'True if enabled, false if disabled.'
										}
									}
								}
							}
						},
						{
							name = 'setLowerLimit',
							description = 'Sets the lower limit.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, usually in meters.'
										}
									}
								}
							}
						},
						{
							name = 'setMaxMotorForce',
							description = 'Set the maximum motor force.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'f',
											description = 'The maximum motor force, usually in N.'
										}
									}
								}
							}
						},
						{
							name = 'setMotorEnabled',
							description = 'Enables/disables the joint motor.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'enable',
											description = 'True to enable, false to disable.'
										}
									}
								}
							}
						},
						{
							name = 'setMotorSpeed',
							description = 'Sets the motor speed.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 's',
											description = 'The motor speed, usually in meters per second.'
										}
									}
								}
							}
						},
						{
							name = 'setUpperLimit',
							description = 'Sets the upper limit.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, usually in meters.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'PulleyJoint',
					description = 'Allows you to simulate bodies connected through pulleys.',
					constructors = {
						'newPulleyJoint'
					},
					functions = {
						{
							name = 'getConstant',
							description = 'Get the total length of the rope.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'length',
											description = 'The length of the rope in the joint.'
										}
									}
								}
							}
						},
						{
							name = 'getGroundAnchors',
							description = 'Get the ground anchor positions in world coordinates.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'a1x',
											description = 'The x coordinate of the first anchor.'
										},
										{
											type = 'number',
											name = 'a1y',
											description = 'The y coordinate of the first anchor.'
										},
										{
											type = 'number',
											name = 'a2x',
											description = 'The x coordinate of the second anchor.'
										},
										{
											type = 'number',
											name = 'a2y',
											description = 'The y coordinate of the second anchor.'
										}
									}
								}
							}
						},
						{
							name = 'getLength1',
							description = 'Get the current length of the rope segment attached to the first body.',
							functions = {
								{
									
									returns = {
										{
											type = 'number',
											name = 'length',
											description = 'The length of the rope segment.'
										}
									}
								}
							}
						},
						{
							name = 'getLength2',
							description = 'Get the current length of the rope segment attached to the second body.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'length',
											description = 'The length of the rope segment.'
										}
									}
								}
							}
						},
						{
							name = 'getMaxLengths',
							description = 'Get the maximum lengths of the rope segments.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'len1',
											description = 'The maximum length of the first rope segment.'
										},
										{
											type = 'number',
											name = 'len2',
											description = 'The maximum length of the second rope segment.'
										}
									}
								}
							}
						},
						{
							name = 'getRatio',
							description = 'Get the pulley ratio.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'ratio',
											description = 'The pulley ratio of the joint.'
										}
									}
								}
							}
						},
						{
							name = 'setConstant',
							description = 'Set the total length of the rope.\n\nSetting a new length for the rope updates the maximum length values of the joint.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'length',
											description = 'The new length of the rope in the joint.'
										}
									}
								}
							}
						},
						{
							name = 'setMaxLengths',
							description = 'Set the maximum lengths of the rope segments.\n\nThe physics module also imposes maximum values for the rope segments. If the parameters exceed these values, the maximum values are set instead of the requested values.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'max1',
											description = 'The new maximum length of the first segment.'
										},
										{
											type = 'number',
											name = 'max2',
											description = 'The new maximum length of the second segment.'
										}
									}
								}
							}
						},
						{
							name = 'setRatio',
							description = 'Set the pulley ratio.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'ratio',
											description = 'The new pulley ratio of the joint.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'RevoluteJoint',
					description = 'Allow two Bodies to revolve around a shared point.',
					constructors = {
						'newRevoluteJoint'
					},
					functions = {
						{
							name = 'enableMotor',
							description = 'Enables/disables the joint motor.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'enable',
											description = 'True to enable, false to disable.'
										}
									}
								}
							}
						},
						{
							name = 'getJointAngle',
							description = 'Get the current joint angle.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'angle',
											description = 'The joint angle in radians.'
										}
									}
								}
							}
						},
						{
							name = 'getJointSpeed',
							description = 'Get the current joint angle speed.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 's',
											description = 'Joint angle speed in radians/second.'
										}
									}
								}
							}
						},
						{
							name = 'getLimits',
							description = 'Gets the joint limits.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, in radians.'
										},
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, in radians.'
										}
									}
								}
							}
						},
						{
							name = 'getLowerLimit',
							description = 'Gets the lower limit.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, in radians.'
										}
									}
								}
							}
						},
						{
							name = 'getMaxMotorTorque',
							description = 'Gets the maximum motor force.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'f',
											description = 'The maximum motor force, in Nm.'
										}
									}
								}
							}
						},
						{
							name = 'getMotorSpeed',
							description = 'Gets the motor speed.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 's',
											description = 'The motor speed, radians per second.'
										}
									}
								}
							}
						},
						{
							name = 'getMotorTorque',
							description = 'Get the current motor force.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'f',
											description = 'The current motor force, in Nm.'
										}
									}
								}
							}
						},
						{
							name = 'getUpperLimit',
							description = 'Gets the upper limit.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, in radians.'
										}
									}
								}
							}
						},
						{
							name = 'isLimitsEnabled',
							description = 'Checks whether limits are enabled.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'enabled',
											description = 'True if enabled, false otherwise.'
										}
									}
								}
							}
						},
						{
							name = 'isMotorEnabled',
							description = 'Checks whether the motor is enabled.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'enabled',
											description = 'True if enabled, false if disabled.'
										}
									}
								}
							}
						},
						{
							name = 'setLimits',
							description = 'Sets the limits.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, in radians.'
										},
										{
											type = 'number',
											name = 'upper',
											description = 'The upper limit, in radians.'
										}
									}
								}
							}
						},
						{
							name = 'setLimitsEnabled',
							description = 'Enables/disables the joint limit.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'enable',
											description = 'True to enable, false to disable.'
										}
									}
								}
							}
						},
						{
							name = 'setLowerLimit',
							description = 'Sets the lower limit.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'lower',
											description = 'The lower limit, in radians.'
										}
									}
								}
							}
						},
						{
							name = 'setMaxMotorTorque',
							description = 'Set the maximum motor force.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'f',
											description = 'The maximum motor force, in Nm.'
										}
									}
								}
							}
						},
						{
							name = 'setMotorSpeed',
							description = 'Sets the motor speed.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 's',
											description = 'The motor speed, radians per second.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'RopeJoint',
					description = 'The RopeJoint enforces a maximum distance between two points on two bodies. It has no other effect.',
					constructors = {
						'newRopeJoint'
					},
					functions = {
						{
							name = 'getMaxLength',
							description = 'Gets the maximum length of a RopeJoint.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'maxLength',
											description = 'The maximum length of the RopeJoint.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'Shape',
					description = 'Shapes are objects used to control mass and collisions.\n\nEvery shape is either a circle or a polygon, and is attached to a Body.',
					constructors = {
						'newPolygonShape',
						'newRectangleShape'
					},
					functions = {
						{
							name = 'computeAABB',
							description = 'Returns the points of the bounding box for the transformed shape.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'tx',
											description = 'The translation of the shape on the x-axis.'
										},
										{
											type = 'number',
											name = 'ty',
											description = 'The translation of the shape on the y-axis.'
										},
										{
											type = 'number',
											name = 'tr',
											description = 'The shape rotation.'
										},
										{
											type = 'number',
											name = 'childIndex',
											default = '1',
											description = 'The index of the child to compute the bounding box of.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'topLeftX',
											description = 'The x position of the top-left point.'
										},
										{
											type = 'number',
											name = 'topLeftY',
											description = 'The y position of the top-left point.'
										},
										{
											type = 'number',
											name = 'bottomRightX',
											description = 'The x position of the bottom-right point.'
										},
										{
											type = 'number',
											name = 'bottomRightY',
											description = 'The y position of the bottom-right point.'
										}
									}
								}
							}
						},
						{
							name = 'computeMass',
							description = 'Computes the mass properties for the shape with the specified density.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'density',
											description = 'The shape density.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x postition of the center of mass.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y postition of the center of mass.'
										},
										{
											type = 'number',
											name = 'mass',
											description = 'The mass of the shape.'
										},
										{
											type = 'number',
											name = 'inertia',
											description = 'The rotational inertia.'
										}
									}
								}
							}
						},
						{
							name = 'destroy',
							description = 'Explicitly destroys the Shape. When you don\'t have time to wait for garbage collection, this function may be used to free the object immediately, but note that an error will occur if you attempt to use the object after calling this function.\nNote that Box2D doesn\'t allow destroying or creating shapes during collision callbacks.',
							functions = {
								{}
							}
						},
						{
							name = 'getBody',
							description = 'Get the Body the shape is attached to.',
							functions = {
								{
									returns = {
										{
											type = 'Body',
											name = 'body',
											description = 'The body the shape is attached to.'
										}
									}
								}
							}
						},
						{
							name = 'getBoundingBox',
							description = 'Gets the bounding box of the shape. This function can be used in a nested fashion with love.graphics.polygon.\n\nA bounding box is the smallest rectangle that encapsulates the entire polygon.\n\nVertexes are returned starting from the bottom-left in a clockwise fashion (bottom-left, top-left, top-right, bottom-right).',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x-component of the first vertex, bottom-left.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y-component of the first vertex, bottom-left.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x-component of the second vertex, top-left.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y-component of the second vertex, top-left.'
										},
										{
											type = 'number',
											name = 'x3',
											description = 'The x-component of the third vertex, top-right.'
										},
										{
											type = 'number',
											name = 'y3',
											description = 'The y-component of the third vertex, top-right.'
										},
										{
											type = 'number',
											name = 'x4',
											description = 'The x-component of the fourth vertex, bottom-right.'
										},
										{
											type = 'number',
											name = 'y4',
											description = 'The y-component of the fourth vertex, bottom-right.'
										}
									}
								}
							}
						},
						{
							name = 'getChildCount',
							description = 'Returns the number of children the shape has.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'count',
											description = 'The number of children.'
										}
									}
								}
							}
						},
						{
							name = 'getData',
							description = 'Get the data set with setData.',
							functions = {
								{
									returns = {
										{
											type = 'any',
											name = 'v',
											description = 'The data previously set, or nil if none.'
										}
									}
								}
							}
						},
						{
							name = 'getDensity',
							description = 'Gets the density of the Shape.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'density',
											description = 'The density of the Shape.'
										}
									}
								}
							}
						},
						{
							name = 'getFilterData',
							description = 'Gets the filter data of the Shape.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'categoryBits',
											description = 'A 16-bit integer representing category membership.'
										},
										{
											type = 'number',
											name = 'maskBits',
											description = 'A 16-bit integer representing masked categories.'
										},
										{
											type = 'number',
											name = 'groupIndex',
											description = 'An integer representing the group index.'
										}
									}
								}
							}
						},
						{
							name = 'getFriction',
							description = 'Gets the friction of this shape.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'friction',
											description = 'The friction of the shape.'
										}
									}
								}
							}
						},
						{
							name = 'getRestitution',
							description = 'Gets the restitution of this shape.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'restitution',
											description = 'The restitution of the shape.'
										}
									}
								}
							}
						},
						{
							name = 'getType',
							description = 'Gets a string representing the Shape. This function can be useful for conditional debug drawing.',
							functions = {
								{
									returns = {
										{
											type = 'ShapeType',
											name = 'type',
											description = 'The type of the Shape.'
										}
									}
								}
							}
						},
						{
							name = 'rayCast',
							description = 'Casts a ray against the shape and returns the surface normal vector and the line position where the ray hit. If the ray missed the shape, nil will be returned. The Shape can be transformed to get it into the desired position.\n\nThe ray starts on the first point of the input line and goes towards the second point of the line. The fourth argument is the maximum distance the ray is going to travel as a scale factor of the input line length.\n\nThe world position of the impact can be calculated by multiplying the line vector with the third return value and adding it to the line starting point.\n\nThere is a bug in 0.8.0 where the normal vector returned by this function gets scaled by love.physics.getMeter.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x position of the input line starting point.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y position of the input line starting point.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x position of the input line end point.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y position of the input line end point.'
										},
										{
											type = 'number',
											name = 'maxFraction',
											description = 'Ray length parameter.'
										},
										{
											type = 'number',
											name = 'tx',
											description = 'The translation of the shape on the x-axis.'
										},
										{
											type = 'number',
											name = 'ty',
											description = 'The translation of the shape on the y-axis.'
										},
										{
											type = 'number',
											name = 'tr',
											description = 'The shape rotation.'
										},
										{
											type = 'number',
											name = 'childIndex',
											default = '1',
											description = 'The index of the child the ray gets cast against.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'xn',
											description = 'The x component of the normal vector of the edge where the ray hit the shape.'
										},
										{
											type = 'number',
											name = 'yn',
											description = 'The y component of the normal vector of the edge where the ray hit the shape.'
										},
										{
											type = 'number',
											name = 'fraction',
											description = 'The position on the input line where the intersection happened as a factor of the line length.'
										}
									}
								}
							}
						},
						{
							name = 'setData',
							description = 'Set data to be passed to the collision callback.\n\nWhen a shape collides, the value set here will be passed to the collision callback as one of the parameters. Typically, you would want to store a table reference here, but any value can be used.',
							functions = {
								{
									arguments = {
										{
											type = 'any',
											name = 'v',
											description = 'Any Lua value.'
										}
									}
								}
							}
						},
						{
							name = 'setDensity',
							description = 'Sets the density of a Shape. Do this before calling Body:setMassFromShapes.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'density',
											description = 'The new density of the Shape.'
										}
									}
								}
							}
						},
						{
							name = 'setFilterData',
							description = 'Sets the filter data for a Shape.\n\nCollision filtering is a system for preventing collision between shapes. For example, say you make a character that rides a bicycle. You want the bicycle to collide with the terrain and the character to collide with the terrain, but you don\'t want the character to collide with the bicycle (because they must overlap). Box2D supports such collision filtering using categories and groups.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'categoryBits',
											description = 'A 16-bit integer representing category membership.'
										},
										{
											type = 'number',
											name = 'maskBits',
											description = 'A 16-bit integer representing masked categories.'
										},
										{
											type = 'number',
											name = 'groupIndex',
											description = 'An integer representing the group index.'
										}
									}
								}
							}
						},
						{
							name = 'setFriction',
							description = 'Sets the friction of the shape. Friction determines how shapes react when they "slide" along other shapes. Low friction indicates a slippery surface, like ice, while high friction indicates a rough surface, like concrete. Range: 0.0 - 1.0.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'friction',
											description = 'The friction of the shape.'
										}
									}
								}
							}
						},
						{
							name = 'setRestitution',
							description = 'Sets the restitution of the shape. Restitution indicates the "bounciness" of the shape. High restitution can be used to model stuff like a rubber ball, while low restitution can be used for "dull" objects, like a bag of sand.\n\nA shape with a restitution of 0 will still bounce a little if the shape it collides with has a restitution higher than 0.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'restitution',
											description = 'The restitution of the shape.'
										}
									}
								}
							}
						},
						{
							name = 'testPoint',
							description = 'Checks whether a point lies inside the shape. This is particularly useful for mouse interaction with the shapes. By looping through all shapes and testing the mouse position with this function, we can find which shapes the mouse touches.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x-component of the point.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y-component of the point.'
										}
									},
									returns = {
										{
											type = 'boolean',
											name = 'hit',
											description = 'True if inside, false if outside'
										}
									}
								}
							}
						},
						{
							name = 'testSegment',
							description = 'Checks whether a line segment intersects a shape. This function will either return the "time" of impact and the surface normal at the point of collision, or nil if the line does not intersect the shape. The "time" is a value between 0.0 and 1.0 and can be used to calculate where the collision occured.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x-component of the first endpoint.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y-component of the first endpoint.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x-component of the second endpoint.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y-component of the second endpoint.'
										}
									},
									returns = {
										{
											type = 'number',
											name = 't',
											description = 'The time of impact, or nil if no impact.'
										},
										{
											type = 'number',
											name = 'xn',
											description = 'The x-component of the surface normal.'
										},
										{
											type = 'number',
											name = 'yn',
											description = 'The y-component of the surface normal.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'WeldJoint',
					description = 'A WeldJoint essentially glues two bodies together.',
					constructors = {
						'newWeldJoint'
					},
					supertypes = {
						'Joint'
					}
				},
				{
					name = 'World',
					description = 'A world is an object that contains all bodies and joints.',
					constructors = {
						'newWorld'
					},
					functions = {
						{
							name = 'destroy',
							description = 'Destroys the world, taking all bodies, joints, fixtures and their shapes with it.\n\nAn error will occur if you attempt to use any of the destroyed objects after calling this function.',
							functions = {
								{}
							}
						},
						{
							name = 'getAllowSleeping',
							description = 'Returns the sleep behaviour of the world.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'allowSleep',
											description = 'True if the bodies are allowed to sleep or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'getBodyCount',
							description = 'Get the number of bodies in the world.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'n',
											description = 'The number of bodies in the world.'
										}
									}
								}
							}
						},
						{
							name = 'getBodyList',
							description = 'Returns a table with all bodies.',
							functions = {
								{
									returns = {
										{
											type = 'table',
											name = 'bodies',
											description = 'A sequence with all bodies.'
										}
									}
								}
							}
						},
						{
							name = 'getCallbacks',
							description = 'Get functions to be called when two shapes collide.',
							functions = {
								{
									returns = {
										{
											type = 'function',
											name = 'add',
											description = 'Called when two shapes first collide.'
										},
										{
											type = 'function',
											name = 'persist',
											description = 'Called each frame, if collision lasts more than 1 frame.'
										},
										{
											type = 'function',
											name = 'remove',
											description = 'Called when two shapes finish colliding.'
										},
										{
											type = 'function',
											name = 'result',
											description = 'No idea. Never seems to be called...'
										}
									}
								}
							}
						},
						{
							name = 'getContactCount',
							description = 'Returns the number of contacts in the world.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'n',
											description = 'The number of contacts in the world.'
										}
									}
								}
							}
						},
						{
							name = 'getContactFilter',
							description = 'Returns the function for collision filtering.',
							functions = {
								{
									returns = {
										{
											type = 'function',
											name = 'contactFilter',
											description = 'The function that handles the contact filtering.'
										}
									}
								}
							}
						},
						{
							name = 'getContactList',
							description = 'Returns a table with all contacts.',
							functions = {
								{
									returns = {
										{
											type = 'table',
											name = 'contacts',
											description = 'A sequence with all contacts.'
										}
									}
								}
							}
						},
						{
							name = 'getGravity',
							description = 'Get the gravity of the world.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'x',
											description = 'The x component of gravity.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y component of gravity.'
										}
									}
								}
							}
						},
						{
							name = 'getJointCount',
							description = 'Get the number of joints in the world.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'n',
											description = 'The number of joints in the world.'
										}
									}
								}
							}
						},
						{
							name = 'getJointList',
							description = 'Returns a table with all joints.',
							functions = {
								{
									returns = {
										{
											type = 'table',
											name = 'joints',
											description = 'A sequence with all joints.'
										}
									}
								}
							}
						},
						{
							name = 'isAllowSleep',
							description = 'Get the sleep behaviour of the world.\n\nA sleeping body is much more efficient to simulate than when awake.\n\nIf sleeping is allowed, any body that has come to rest will sleep.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'permission',
											description = 'Permission for any body to sleep.'
										}
									}
								}
							}
						},
						{
							name = 'isLocked',
							description = 'Returns if the world is updating its state.\n\nThis will return true inside the callbacks from World:setCallbacks.',
							functions = {
								{
									returns = {
										{
											type = 'boolean',
											name = 'locked',
											description = 'Will be true if the world is in the process of updating its state.'
										}
									}
								}
							}
						},
						{
							name = 'queryBoundingBox',
							description = 'Calls a function for each fixture inside the specified area.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'topLeftX',
											description = 'The x position of the top-left point.'
										},
										{
											type = 'number',
											name = 'topLeftY',
											description = 'The y position of the top-left point.'
										},
										{
											type = 'number',
											name = 'bottomRightX',
											description = 'The x position of the bottom-right point.'
										},
										{
											type = 'number',
											name = 'bottomRightY',
											description = 'The y position of the bottom-right point.'
										},
										{
											type = 'function',
											name = 'callback',
											description = 'This function gets passed one argument, the fixture, and should return a boolean. The search will continue if it is true or stop if it is false.'
										}
									}
								}
							}
						},
						{
							name = 'rayCast',
							description = 'Casts a ray and calls a function with the fixtures that intersect it. You cannot make any assumptions about the order of the callbacks.\n\nEach time the function gets called, 6 arguments get passed to it. The first is the fixture intersecting the ray. The second and third are the coordinates of the intersection point. The fourth and fifth is the surface normal vector of the shape edge. The sixth argument is the position of the intersection on the ray as a number from 0 to 1 (or even higher if the ray length was changed with the return value).\n\nThe ray can be controlled with the return value. A positive value sets a new ray length where 1 is the default value. A value of 0 terminates the ray. If the callback function returns -1, the intersection gets ignored as if it didn\'t happen.\n\nThere is a bug in 0.8.0 where the normal vector passed to the callback function gets scaled by love.physics.getMeter.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x1',
											description = 'The x position of the starting point of the ray.'
										},
										{
											type = 'number',
											name = 'y1',
											description = 'The y position of the starting point of the ray.'
										},
										{
											type = 'number',
											name = 'x2',
											description = 'The x position of the end point of the ray.'
										},
										{
											type = 'number',
											name = 'y2',
											description = 'The y position of the end point of the ray.'
										},
										{
											type = 'function',
											name = 'callback',
											description = 'This function gets six arguments and should return a number.'
										}
									}
								}
							}
						},
						{
							name = 'setAllowSleeping',
							description = 'Set the sleep behaviour of the world.\n\nA sleeping body is much more efficient to simulate than when awake.\n\nIf sleeping is allowed, any body that has come to rest will sleep.',
							functions = {
								{
									arguments = {
										{
											type = 'boolean',
											name = 'allowSleep',
											description = 'True if the bodies are allowed to sleep or false if not.'
										}
									}
								}
							}
						},
						{
							name = 'setCallbacks',
							description = 'Set functions to be called when shapes collide.\n\nFour Lua functions can be given as arguments. The value nil can be given for events that are uninteresting.\n\nWhen called, each function will be passed three arguments. The first two arguments (one for each shape) will pass data that has been set with Shape:setData (or nil). The third argument passes the Contact between the two shapes.\n\nUsing Shape:destroy when there is an active remove callback can lead to a crash. It is possible to work around this issue by only destroying object that are not in active contact with anything.',
							functions = {
								{
									arguments = {
										{
											type = 'function',
											name = 'add',
											description = 'Called when two shapes first collide.'
										},
										{
											type = 'function',
											name = 'persist',
											description = 'Called each frame, if collision lasts more than 1 frame.'
										},
										{
											type = 'function',
											name = 'remove',
											description = 'Called when two shapes finish colliding.'
										},
										{
											type = 'function',
											name = 'result',
											description = 'Called after a collision has been calculated. Note: This callback is not properly bound in LVE at the time of writing, as a result, this callback does not get called, nor do proper arguments get passed for it.'
										}
									}
								}
							}
						},
						{
							name = 'setGravity',
							description = 'Set the gravity of the world.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'x',
											description = 'The x component of gravity.'
										},
										{
											type = 'number',
											name = 'y',
											description = 'The y component of gravity.'
										}
									}
								}
							}
						},
						{
							name = 'update',
							description = 'Update the state of the world.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'dt',
											description = 'The time (in seconds) to advance the physics simulation.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'getDistance',
					description = 'Returns the two closest points between two fixtures and their distance.',
					functions = {
						{
							arguments = {
								{
									type = 'Fixture',
									name = 'fixture1',
									description = 'The first fixture.'
								},
								{
									type = 'Fixture',
									name = 'fixture2',
									description = 'The second fixture.'
								}
							},
							returns = {
								{
									type = 'number',
									name = 'distance',
									description = 'The distance of the two points.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The x-coordinate of the first point.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The y-coordinate of the first point.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The x-coordinate of the second point.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The y-coordinate of the second point.'
								}
							}
						}
					}
				},
				{
					name = 'getMeter',
					description = 'Get the scale of the world.\n\nThe world scale is the number of pixels per meter. Try to keep your shape sizes less than 10 times this scale.\n\nThis is important because the physics in Box2D is tuned to work well for objects of size 0.1m up to 10m. All physics coordinates are divided by this number for the physics calculations.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'scale',
									description = 'The size of 1 meter in pixels.'
								}
							}
						}
					}
				},
				{
					name = 'newBody',
					description = 'Creates a new body.\n\nThere are three types of bodies. Static bodies do not move, have a infinite mass, and can be used for level boundaries. Dynamic bodies are the main actors in the simulation, they collide with everything. Kinematic bodies do not react to forces and only collide with dynamic bodies.\n\nThe mass of the body gets calculated when a Fixture is attached or removed, but can be changed at any time with Body:setMass or Body:resetMassData.',
					functions = {
						{
							arguments = {
								{
									type = 'World',
									name = 'world',
									description = 'The world to create the body in.'
								},
								{
									type = 'number',
									name = 'x',
									default = '0',
									description = 'The x position of the body.'
								},
								{
									type = 'number',
									name = 'y',
									default = '0',
									description = 'The y position of the body.'
								},
								{
									type = 'BodyType',
									name = 'type',
									default = '"static"',
									description = 'The type of the body.'
								}
							},
							returns = {
								{
									type = 'Body',
									name = 'body',
									description = 'A new body.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'World',
									name = 'world',
									description = 'The world to create the body in.'
								},
								{
									type = 'number',
									name = 'x',
									default = '0',
									description = 'The x position of the body.'
								},
								{
									type = 'number',
									name = 'y',
									default = '0',
									description = 'The y position of the body.'
								},
								{
									type = 'string',
									name = 't',
									default = '0',
									description = 'Whether the body is static or dynamic.'
								}
							},
							returns = {
								{
									type = 'Body',
									name = 'body',
									description = 'A new body.'
								}
							}
						}
					}
				},
				{
					name = 'newChainShape',
					description = 'Creates a chain shape.',
					functions = {
						{
							arguments = {
								{
									type = 'boolean',
									name = 'loop',
									description = 'If the chain should loop back to the first point.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The x position of the first point.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The y position of the first point.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The x position of the second point.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The y position of the second point.'
								}
							},
							returns = {
								{
									type = 'ChainShape',
									name = 'shape',
									description = 'The new shape.'
								}
							}
						}
					}
				},
				{
					name = 'newCircleShape',
					description = 'Create a new CircleShape at (x,y) in local coordinates.\n\nlove.physics.newCircleShape() anchors from the center of the shape by default.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body',
									description = 'The body to attach the shape to.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x offset of the circle.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y offset of the circle.'
								},
								{
									type = 'number',
									name = 'radius',
									description = 'The radius of the circle.'
								}
							},
							returns = {
								{
									type = 'CircleShape',
									name = 'shape',
									description = 'A new CircleShape.'
								}
							}
						}
					}
				},
				{
					name = 'newDistanceJoint',
					description = 'Create a distance joint between two bodies.\n\nThis joint constrains the distance between two points on two bodies to be constant. These two points are specified in world coordinates and the two bodies are assumed to be in place when this joint is created. The first anchor point is connected to the first body and the second to the second body, and the points define the length of the distance joint.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to attach to the joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to attach to the joint.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The x position of the first anchor point.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The y position of the first anchor point.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The x position of the second anchor point.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The y position of the second anchor point.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'Joint',
									name = 'joint',
									description = 'The new distance joint.'
								}
							}
						}
					}
				},
				{
					name = 'newEdgeShape',
					description = 'Creates a edge shape.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The x position of the first point.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The y position of the first point.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x position of the second point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y position of the second point.'
								}
							},
							returns = {
								{
									type = 'EdgeShape',
									name = 'shape',
									description = 'The new shape.'
								}
							}
						}
					}
				},
				{
					name = 'newFixture',
					description = 'Creates and attaches a Fixture to a body.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body',
									description = 'The body which gets the fixture attached.'
								},
								{
									type = 'Shape',
									name = 'shape',
									description = 'The shape of the fixture.'
								},
								{
									type = 'number',
									name = 'density',
									default = '1',
									description = 'The density of the fixture.'
								}
							},
							returns = {
								{
									type = 'Fixture',
									name = 'fixture',
									description = 'The new fixture.'
								}
							}
						}
					}
				},
				{
					name = 'newFrictionJoint',
					description = 'Create a friction joint between two bodies. A FrictionJoint applies friction to a body.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to attach to the joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to attach to the joint.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x position of the anchor point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y position of the anchor point.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with eachother.'
								}
							},
							returns = {
								{
									type = 'FrictionJoint',
									name = 'joint',
									description = 'The new FrictionJoint.'
								}
							}
						}
					}
				},
				{
					name = 'newGearJoint',
					description = 'Create a gear joint connecting two joints.\n\nThe gear joint connects two joints that must be either prismatic or revolute joints. Using this joint requires that the joints it uses connect their respective bodies to the ground and have the ground as the first body. When destroying the bodies and joints you must make sure you destroy the gear joint before the other joints.\n\nThe gear joint has a ratio the determines how the angular or distance values of the connected joints relate to each other. The formula coordinate1 + ratio * coordinate2 always has a constant value that is set when the gear joint is created.',
					functions = {
						{
							arguments = {
								{
									type = 'Joint',
									name = 'joint1',
									description = 'The first joint to connect with a gear joint.'
								},
								{
									type = 'Joint',
									name = 'joint2',
									description = 'The second joint to connect with a gear joint.'
								},
								{
									type = 'number',
									name = 'ratio',
									default = '1',
									description = 'The gear ratio.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'Joint',
									name = 'joint',
									description = 'The new gear joint.'
								}
							}
						}
					}
				},
				{
					name = 'newMouseJoint',
					description = 'Create a joint between a body and the mouse.\n\nThis joint actually connects the body to a fixed point in the world. To make it follow the mouse, the fixed point must be updated every timestep (example below).\n\nThe advantage of using a MouseJoint instead of just changing a body position directly is that collisions and reactions to other joints are handled by the physics engine.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body',
									description = 'The body to attach to the mouse.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x position of the connecting point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y position of the connecting point.'
								}
							},
							returns = {
								{
									type = 'Joint',
									name = 'joint',
									description = 'The new mouse joint.'
								}
							}
						}
					}
				},
				{
					name = 'newPolygonShape',
					description = 'Creates a new PolygonShape.\nThis shape can have 8 vertices at most, and must form a convex shape.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body',
									description = 'The body to attach the shape to.'
								},
								{
									type = 'number',
									name = '...',
									description = 'Vertices of the polygon.'
								}
							},
							returns = {
								{
									type = 'PolygonShape',
									name = 'shape',
									description = 'A new PolygonShape.'
								}
							}
						}
					}
				},
				{
					name = 'newPrismaticJoint',
					description = 'Create a prismatic joints between two bodies.\n\nA prismatic joint constrains two bodies to move relatively to each other on a specified axis. It does not allow for relative rotation. Its definition and operation are similar to a revolute joint, but with translation and force substituted for angle and torque.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to connect with a prismatic joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to connect with a prismatic joint.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x coordinate of the anchor point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y coordinate of the anchor point.'
								},
								{
									type = 'number',
									name = 'ax',
									description = 'The x coordinate of the axis vector.'
								},
								{
									type = 'number',
									name = 'ay',
									description = 'The y coordinate of the axis vector.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'PrismaticJoint',
									name = 'joint',
									description = 'The new prismatic joint.'
								}
							}
						}
					}
				},
				{
					name = 'newPulleyJoint',
					description = 'Create a pulley joint to join two bodies to each other and the ground.\n\nThe pulley joint simulates a pulley with an optional block and tackle. If the ratio parameter has a value different from one, then the simulated rope extends faster on one side than the other. In a pulley joint the total length of the simulated rope is the constant length1 + ratio * length2, which is set when the pulley joint is created.\n\nPulley joints can behave unpredictably if one side is fully extended. It is recommended that the method setMaxLengths  be used to constrain the maximum lengths each side can attain.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to connect with a pulley joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to connect with a pulley joint.'
								},
								{
									type = 'number',
									name = 'gx1',
									description = 'The x coordinate of the first body\'s ground anchor.'
								},
								{
									type = 'number',
									name = 'gy1',
									description = 'The y coordinate of the first body\'s ground anchor.'
								},
								{
									type = 'number',
									name = 'gx2',
									description = 'The x coordinate of the second body\'s ground anchor.'
								},
								{
									type = 'number',
									name = 'gy2',
									description = 'The y coordinate of the second body\'s ground anchor.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The x coordinate of the pulley joint anchor in the first body.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The y coordinate of the pulley joint anchor in the first body.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The x coordinate of the pulley joint anchor in the second body.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The y coordinate of the pulley joint anchor in the second body.'
								},
								{
									type = 'number',
									name = 'ratio',
									default = '1',
									description = 'The joint ratio.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'true',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'Joint',
									name = 'joint',
									description = 'The new pulley joint.'
								}
							}
						}
					}
				},
				{
					name = 'newRectangleShape',
					description = 'Shorthand for creating rectangluar PolygonShapes.\n\nThe rectangle will be created at (x,y) in local coordinates.\n\nlove.physics.newRectangleShape() anchors from the center of the shape by default.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body',
									description = 'The Body to attach the Shape to.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The offset along the x-axis.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The offset along the y-axis.'
								},
								{
									type = 'number',
									name = 'width',
									description = 'The width of the rectangle.'
								},
								{
									type = 'number',
									name = 'height',
									description = 'The height of the rectangle.'
								},
								{
									type = 'number',
									name = 'angle',
									default = '0',
									description = 'The initial angle of the rectangle.'
								}
							},
							returns = {
								{
									type = 'PolygonShape',
									name = 'shape',
									description = 'A new PolygonShape.'
								}
							}
						}
					}
				},
				{
					name = 'newRevoluteJoint',
					description = 'Creates a pivot joint between two bodies.\n\nThis joint connects two bodies to a point around which they can pivot.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to connect with a Revolute Joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to connect with a Revolute Joint.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x position of the connecting point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y position of the connecting point.'
								},
								{
									type = 'number',
									name = 'collideConnected',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'Joint',
									name = 'joint',
									description = 'The new revolute joint.'
								}
							}
						}
					}
				},
				{
					name = 'newRopeJoint',
					description = 'Create a joint between two bodies. Its only function is enforcing a max distance between these bodies.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to attach to the joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to attach to the joint.'
								},
								{
									type = 'number',
									name = 'x1',
									description = 'The x position of the first anchor point.'
								},
								{
									type = 'number',
									name = 'y1',
									description = 'The y position of the first anchor point.'
								},
								{
									type = 'number',
									name = 'x2',
									description = 'The x position of the second anchor point.'
								},
								{
									type = 'number',
									name = 'y2',
									description = 'The y position of the second anchor point.'
								},
								{
									type = 'number',
									name = 'maxLength',
									description = 'The maximum distance for the bodies.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'RopeJoint',
									name = 'joint',
									description = 'The new RopeJoint.'
								}
							}
						}
					}
				},
				{
					name = 'newWeldJoint',
					description = 'Create a friction joint between two bodies. A WeldJoint essentially glues two bodies together.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body to attach to the joint.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body to attach to the joint.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x position of the anchor point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y position of the anchor point.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'WeldJoint',
									name = 'joint',
									description = 'The new WeldJoint.'
								}
							}
						}
					}
				},
				{
					name = 'newWheelJoint',
					description = 'Creates a wheel joint.',
					functions = {
						{
							arguments = {
								{
									type = 'Body',
									name = 'body1',
									description = 'The first body.'
								},
								{
									type = 'Body',
									name = 'body2',
									description = 'The second body.'
								},
								{
									type = 'number',
									name = 'x',
									description = 'The x position of the anchor point.'
								},
								{
									type = 'number',
									name = 'y',
									description = 'The y position of the anchor point.'
								},
								{
									type = 'number',
									name = 'ax',
									description = 'The x position of the axis unit vector.'
								},
								{
									type = 'number',
									name = 'ay',
									description = 'The y position of the axis unit vector.'
								},
								{
									type = 'boolean',
									name = 'collideConnected',
									default = 'false',
									description = 'Specifies whether the two bodies should collide with each other.'
								}
							},
							returns = {
								{
									type = 'WheelJoint',
									name = 'joint',
									description = 'The new WheelJoint.'
								}
							}
						}
					}
				},
				{
					name = 'newWorld',
					description = 'Creates a new World.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'xg',
									default = '0',
									description = 'The x component of gravity.'
								},
								{
									type = 'number',
									name = 'yg',
									default = '0',
									description = 'The y component of gravity.'
								},
								{
									type = 'boolean',
									name = 'sleep',
									default = 'true',
									description = 'Whether the bodies in this world are allowed to sleep.'
								}
							},
							returns = {
								{
									type = 'World',
									name = 'world',
									description = 'A brave new World.'
								}
							}
						}
					}
				},
				{
					name = 'setMeter',
					description = 'Sets the meter scale factor.\n\nAll coordinates in the physics module are divided by this number, creating a convenient way to draw the objects directly to the screen without the need for graphics transformations.\n\nIt is recommended to create shapes no larger than 10 times the scale. This is important because Box2D is tuned to work well with shape sizes from 0.1 to 10 meters.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 'scale',
									description = 'The scale factor as an integer.'
								}
							}
						}
					}
				}
			},
			enums = {
				{
					name = 'BodyType',
					constants = {
						{
							name = 'static',
							description = 'Static bodies do not move.'
						},
						{
							name = 'dynamic',
							description = 'Dynamic bodies collide with all bodies.'
						},
						{
							name = 'kinematic',
							description = 'Kinematic bodies only collide with dynamic bodies.'
						}
					}
				},
				{
					name = 'JointType',
					constants = {
						{
							name = 'distance',
							description = 'A DistanceJoint.'
						},
						{
							name = 'gear',
							description = 'A GearJoint.'
						},
						{
							name = 'mouse',
							description = 'A MouseJoint.'
						},
						{
							name = 'prismatic',
							description = 'A PrismaticJoint.'
						},
						{
							name = 'pulley',
							description = 'A PulleyJoint.'
						},
						{
							name = 'revolute',
							description = 'A RevoluteJoint.'
						},
					}
				},
				{
					name = 'ShapeType',
					description = 'The different types of Shapes, as returned by Shape:getType.',
					constants = {
						{
							name = 'circle',
							description = 'The Shape is a CircleShape.'
						},
						{
							name = 'polygon',
							description = 'The Shape is a PolygonShape.'
						},
						{
							name = 'edge',
							description = 'The Shape is a EdgeShape.'
						},
						{
							name = 'chain',
							description = 'The Shape is a ChainShape.'
						}
					}
				}
			}
		},
		{
			name = 'sound',
			description = 'This module is responsible for decoding sound files. It can\'t play the sounds, see love.audio for that.',
			types = {
				{
					name = 'Decoder',
					description = 'An object which can gradually decode a sound file.',
					constructors = {
						'newDecoder'
					},
					functions = {
						{
							name = 'getBits',
							description = 'Returns the number of bits per sample.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'bitSize',
											description = 'Either 8 or 16.'
										}
									}
								}
							}
						},
						{
							name = 'getChannels',
							description = 'Returns the number of channels in the stream.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'channels',
											description = '1 for mono, 2 for stereo.'
										}
									}
								}
							}
						},
						{
							name = 'getSampleRate',
							description = 'Returns the sample rate of the Decoder.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'rate',
											description = 'Number of samples per second.'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				},
				{
					name = 'SoundData',
					description = 'Contains raw audio samples. You can not play SoundData back directly. You must wrap a Source object around it.',
					constructors = {
						'newSoundData'
					},
					functions = {
						{
							name = 'getBits',
							description = 'Returns the number of bits per sample.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'bitSize',
											description = 'Either 8 or 16.'
										}
									}
								}
							}
						},
						{
							name = 'getChannels',
							description = 'Returns the number of channels in the stream.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'channels',
											description = '1 for mono, 2 for stereo.'
										}
									}
								}
							}
						},
						{
							name = 'getSample',
							description = 'Gets the sample at the specified position.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'i',
											description = 'The position of the sample (0 means first sample).'
										}
									},
									returns = {
										{
											type = 'number',
											name = 'sample',
											description = 'The normalized sample (range -1.0 to 1.0).'
										}
									}
								}
							}
						},
						{
							name = 'getSampleRate',
							description = 'Returns the sample rate of the SoundData.',
							functions = {
								{
									returns = {
										{
											type = 'number',
											name = 'rate',
											description = 'Number of samples per second.'
										}
									}
								}
							}
						},
						{
							name = 'setSample',
							description = 'Sets the sample at the specified position.',
							functions = {
								{
									arguments = {
										{
											type = 'number',
											name = 'i',
											description = 'The position of the sample (0 means first sample).'
										},
										{
											type = 'number',
											name = 'sample',
											description = 'A normalized sample (range -1.0 to 1.0).'
										}
									}
								}
							}
						}
					},
					supertypes = {
						'Data',
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'newDecoder',
					description = 'Attempts to find a decoder for the encoded sound data in the specified file.',
					functions = {
						{
							arguments = {
								{
									type = 'File',
									name = 'file',
									description = 'The file with encoded sound data.'
								},
								{
									type = 'number',
									name = 'buffer',
									default = '2048',
									description = 'The size of each decoded chunk, in bytes.'
								}
							},
							returns = {
								{
									type = 'Decoder',
									name = 'decoder',
									description = 'A new Decoder object.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The filename of the file with encoded sound data.'
								},
								{
									type = 'number',
									name = 'buffer',
									default = '2048',
									description = 'The size of each decoded chunk, in bytes.'
								}
							},
							returns = {
								{
									type = 'Decoder',
									name = 'decoder',
									description = 'A new Decoder object.'
								}
							}
						}
					}
				},
				{
					name = 'newSoundData',
					description = 'Creates new SoundData from a Decoder or file. It\'s also possible to create SoundData with a custom sample rate, channel and bit depth.\n\nThe sound data will be decoded to the memory in a raw format. It is recommended to create only short sounds like effects, as a 3 minute song uses 30 MB of memory this way.',
					functions = {
						{
							arguments = {
								{
									type = 'Decoder',
									name = 'decoder',
									description = 'Decode data from this Decoder until EOF.'
								}
							},
							returns = {
								{
									type = 'SoundData',
									name = 'soundData',
									description = 'A new SoundData object.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'string',
									name = 'filename',
									description = 'The file name of the file to load.'
								}
							},
							returns = {
								{
									type = 'SoundData',
									name = 'soundData',
									description = 'A new SoundData object.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'number',
									name = 'samples',
									description = 'Total number of samples.'
								},
								{
									type = 'number',
									name = 'rate',
									default = '44100',
									description = 'Number of samples per second'
								},
								{
									type = 'number',
									name = 'bits',
									default = '16',
									description = 'Bits per sample (8 or 16).'
								},
								{
									type = 'number',
									name = 'channels',
									default = '2',
									description = 'Either 1 for mono or 2 for stereo.'
								}
							},
							returns = {
								{
									type = 'SoundData',
									name = 'soundData',
									description = 'A new SoundData object.'
								}
							}
						}
					}
				}
			}
		},
		{
			name = 'thread',
			description = 'Allows you to work with threads.\n\nThreads are separate Lua environments, running in parallel to the main code. As their code runs separately, they can be used to compute complex operations without adversely affecting the frame rate of the main thread. However, as they are separate environments, they cannot access the variables and functions of the main thread, and communication between threads is limited\n\nWhen a Thread is started, it only loads the love.thread module. Every other module has to be loaded with require.\n\nThe love.graphics module has several restrictions and therefore should only be used in the main thread.',
			types = {
				{
					name = 'Thread',
					description = 'A Thread is a chunk of code that can run in parallel with other threads.\n\nThreads will place all Lua errors in "error". To retrieve the error, call thread:receive(\'error\') in the main thread.',
					constructors = {
						'newThread'
					},
					functions = {
						{
							name = 'demand',
							description = 'Receive a message from a thread. Wait for the message to exist before returning. (Can return nil in case of an error in the thread.)',
							functions = {
								{
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'The name of the message.'
										}
									},
									returns = {
										{
											type = 'value',
											name = 'value',
											description = 'The contents of the message.'
										}
									}
								}
							},
							{
								name = 'get',
								description = 'Get a value (cross-threads). Returns nil when a message is not in the message box.',
								functions = {
									{
										arguments = {
											{
												type = 'string',
												name = 'name',
												description = 'The name of the message.'
											}
										},
										returns = {
											{
												type = 'mixed',
												name = 'value',
												description = 'The contents of the message or nil when no message in message box.'
											}
										}
									}
								}
							},
							{
								name = 'getName',
								description = 'Get the name of a thread.',
								functions = {
									{
										returns = {
											{
												type = 'string',
												name = 'name',
												description = 'The name of the thread.'
											}
										}
									}
								}
							},
							{
								name = 'peek',
								description = 'Receive a message from a thread, but leave it in the message box.',
								functions = {
									{
										arguments = {
											{
												type = 'string',
												name = 'name',
												description = 'The name of the message.'
											}
										},
										returns = {
											{
												type = 'value',
												name = 'value',
												description = 'The contents of the message.'
											}
										}
									}
								}
							},
							{
								name = 'set',
								description = 'Set a value (cross-threads).',
								functions = {
									arguments = {
										{
											type = 'string',
											name = 'name',
											description = 'The name of the message.'
										},
										{
											type = 'mixed',
											name = 'value',
											description = 'The contents of the message.'
										}
									}
								}
							},
							{
								name = 'start',
								description = 'Starts the thread.',
								functions = {
									{}
								}
							},
							{
								name = 'wait',
								description = 'Wait for a thread to finish. This call will block until the thread finishes.',
								functions = {
									{}
								}
							}
						}
					},
					supertypes = {
						'Object'
					}
				}
			},
			functions = {
				{
					name = 'getThread',
					description = 'Look for a thread and get its object.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name of the thread to return.'
								}
							},
							returns = {
								{
									type = 'Thread',
									name = 'thread',
									description = 'The thread with that name.'
								}
							}
						},
						{
							returns = {
								{
									type = 'Thread',
									name = 'thread',
									description = 'The current thread.'
								}
							}
						}
					}
				},
				{
					name = 'getThreads',
					description = 'Get all threads.',
					functions = {
						{
							returns = {
								{
									type = 'table',
									name = 'threads',
									description = 'A table containing all threads indexed by their names.'
								}
							}
						}
					}
				},
				{
					name = 'newThread',
					description = 'Creates a new Thread from a File or Data Object.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name of the thread.'
								},
								{
									type = 'string',
									name = 'filename',
									description = 'The name of the File to use as source.'
								}
							},
							returns = {
								{
									type = 'Thread',
									name = 'thread',
									description = 'A new Thread that has yet to be started.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name of the thread.'
								},
								{
									type = 'File',
									name = 'file',
									description = 'The file to use as source.'
								}
							},
							returns = {
								{
									type = 'Thread',
									name = 'thread',
									description = 'A new Thread that has yet to be started.'
								}
							}
						},
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name of the thread.'
								},
								{
									type = 'Data',
									name = 'data',
									description = 'The name of the File to use as source.'
								}
							},
							returns = {
								{
									type = 'Thread',
									name = 'thread',
									description = 'A new Thread that has yet to be started.'
								}
							}
						}
					}
				}
			}
		},
		{
			name = 'timer',
			description = 'Provides an interface to the user\'s clock.',
			functions = {
				{
					name = 'getDelta',
					description = 'Returns the time between the last two frames.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'dt',
									description = 'The time passed (in seconds).'
								}
							}
						}
					}
				},
				{
					name = 'getFPS',
					description = 'Returns the current frames per second.\n\nDisplaying the FPS with love.graphics.print or love.graphics.setCaption can have an impact on this value. Keep this in mind while benchmarking your game.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'fps',
									description = 'The current FPS.'
								}
							}
						}
					}
				},
				{
					name = 'getMicroTime',
					description = 'Returns the value of a timer with an unspecified starting time. The time is accurate to the microsecond, and is limited to 24 hours.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 't',
									description = 'The time passed (in seconds).'
								}
							}
						}
					}
				},
				{
					name = 'getTime',
					description = 'Returns the value of a timer with an unspecified starting time. This function should only be used to calculate differences between points in time, as the starting time of the timer is unknown.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'time',
									description = 'The time in seconds.'
								}
							}
						}
					}
				},
				{
					name = 'sleep',
					description = 'Sleeps the program for the specified amount of time.',
					functions = {
						{
							arguments = {
								{
									type = 'number',
									name = 's',
									description = 'Seconds to sleep for.'
								}
							}
						}
					}
				},
				{
					name = 'step',
					description = 'Measures the time between two frames. Calling this changes the return value of love.timer.getDelta.',
					functions = {
						{}
					}
				}
			}
		}
	},
	types = {
		{
			name = 'Data',
			description = 'The superclass of all data.',
			functions = {
				{
					name = 'getPointer',
					description = 'Gets a pointer to the Data.',
					functions = {
						{
							returns = {
								{
									type = 'light userdata',
									name = 'ptr',
									description = 'A raw pointer to the Data.'
								},
								{
									type = 'number',
									name = 'size',
									description = 'The size of the Data in bytes.'
								}
							}
						}
					}
				},
				{
					name = 'getSize',
					description = 'Gets the size of the Data.',
					functions = {
						{
							returns = {
								{
									type = 'number',
									name = 'size',
									description = 'The size of the Data in bytes.'
								}
							}
						}
					}
				}
			},
			supertypes = {
				'Object'
			}
		},
		{
			name = 'Object',
			description = 'The superclass of all LVE types.',
			functions = {
				{
					name = 'type',
					description = 'Gets the type of the object as a string.',
					functions = {
						{
							returns = {
								{
									type = 'string',
									name = 'type',
									description = 'The type as a string.'
								}
							}
						}
					}
				},
				{
					name = 'typeOf',
					description = 'Checks whether an object is of a certain type. If the object has the type with the specified name in its hierarchy, this function will return true.',
					functions = {
						{
							arguments = {
								{
									type = 'string',
									name = 'name',
									description = 'The name of the type to check for.'
								}
							},
							returns = {
								{
									type = 'boolean',
									name = 'b',
									description = 'True if the object is of the specified type, false otherwise.'
								}
							}
						}
					}
				}
			}
		}
	},
	callbacks = {
		{
			name = 'draw',
			description = 'Callback function used to draw on the screen every frame.',
			functions = {
				{}
			}
		},
		{
			name = 'focus',
			description = 'Callback function triggered when window receives or loses focus.',
			functions = {
				{
					arguments = {
						{
							type = 'boolean',
							name = 'f',
							description = 'Window focus.'
						}
					}
				}
			}
		},
		{
			name = 'joystickpressed',
			description = 'Called when a joystick button is pressed.',
			functions = {
				{
					arguments = {
						{
							type = 'number',
							name = 'joystick',
							description = 'The joystick number.'
						},
						{
							type = 'number',
							name = 'button',
							description = 'The button number.'
						}
					}
				}
			}
		},
		{
			name = 'joystickreleased',
			description = 'Called when a joystick button is released.',
			functions = {
				{
					arguments = {
						{
							type = 'number',
							name = 'joystick',
							description = 'The joystick number.'
						},
						{
							type = 'number',
							name = 'button',
							description = 'The button number.'
						}
					}
				}
			}
		},
		{
			name = 'keypressed',
			description = 'Callback function triggered when a key is pressed.',
			functions = {
				{
					arguments = {
						{
							type = 'KeyConstant',
							name = 'key',
							description = 'Character of the key pressed.'
						},
						{
							type = 'number',
							name = 'unicode',
							description = 'The unicode number of the key pressed.'
						}
					}
				}
			}
		},
		{
			name = 'keyreleased',
			description = 'Callback function triggered when a key is released.',
			functions = {
				{
					arguments = {
						{
							type = 'KeyConstant',
							name = 'key',
							description = 'Character of the key released.'
						}
					}
				}
			}
		},
		{
			name = 'load',
			description = 'This function is called exactly once at the beginning of the game.',
			functions = {
				{
					arguments = {
						{
							type = 'table',
							name = 'arg',
							description = 'Command line arguments given to the game.'
						}
					}
				}
			}
		},
		{
			name = 'mousepressed',
			description = 'Callback function triggered when a mouse button is pressed.',
			functions = {
				{
					arguments = {
						{
							type = 'number',
							name = 'x',
							description = 'Mouse x position.'
						},
						{
							type = 'number',
							name = 'y',
							description = 'Mouse y position.'
						},
						{
							type = 'MouseConstant',
							name = 'button',
							description = 'Mouse button pressed.'
						}
					}
				}
			}
		},
		{
			name = 'mousereleased',
			description = 'Callback function triggered when a mouse button is released.',
			functions = {
				{
					arguments = {
						{
							type = 'number',
							name = 'x',
							description = 'Mouse x position.'
						},
						{
							type = 'number',
							name = 'y',
							description = 'Mouse y position.'
						},
						{
							type = 'MouseConstant',
							name = 'button',
							description = 'Mouse button released.'
						}
					}
				}
			}
		},
		{
			name = 'quit',
			description = 'Callback function triggered when the game is closed.',
			functions = {
				{
					returns = {
						{
							type = 'boolean',
							name = 'r',
							description = 'Abort quitting. If true, do not close the game.'
						}
					}
				}
			}
		},
		{
			name = 'run',
			description = 'The main function, containing the main loop. A sensible default is used when left out.',
			functions = {
				{}
			}
		},
		{
			name = 'update',
			description = 'Callback function triggered when a key is pressed.',
			functions = {
				{
					arguments = {
						{
							type = 'number',
							name = 'dt',
							description = 'Time since the last update in seconds.'
						}
					}
				}
			}
		}
	}
}
